@@ -8,26 +8,38 @@
 (defvar ange-ftp-tmp-name-template nil)
 (defvar auto-image-file-mode nil)
 (defvar coding-category-list nil)
+(defvar current-menubar nil)
 (defvar default-file-name-coding-system nil)
+(defvar default-toolbar nil)
+(defvar default-toolbar-visible-p nil)
+(defvar dnd-protocol-alist nil)
 (defvar elp-function-list nil)
 (defvar elp-results-buffer nil)
 (defvar find-file-hook nil)
 (defvar inhibit-eol-conversion nil)
 (defvar inhibit-point-motion-hooks nil)
 (defvar jka-compr-inhibit nil)
+(defvar last-pressed-toolbar-button nil)
 (defvar mark-active nil)
 (defvar max-mini-window-height nil)
+(defvar mew-draft-toolbar nil)
+(defvar mew-icon-separate-spec nil)
+(defvar mew-message-toolbar nil)
+(defvar mew-summary-toolbar nil)
 (defvar mode-line-position nil)
 (defvar mule-version nil)
 (defvar profile-buffer nil)
 (defvar profile-functions-list nil)
+(defvar scrollbar-height nil)
+(defvar system-name nil)
 (defvar system-time-locale nil)
+(defvar toolbar-active nil)
+(defvar toolbar-map nil)
 (defvar transient-mark-mode nil)
 (defvar w32-get-true-file-link-count nil)
 (defvar w32-start-process-show-window nil)
 (defvar w3m-content-type-alist nil)
 (defvar w3m-namazu-index-alist nil)
-(defvar dnd-protocol-alist nil)
 (defvar x-dnd-test-function nil)
 
 (defun amultibyte-string-p (&rest args))
@@ -39,6 +51,8 @@
 (defun create-image (&rest args))
 (defun define-process-argument-editing (&rest args))
 (defun display-graphic-p (&rest args))
+(defun dnd-get-local-file-name (&rest args))
+(defun dnd-get-local-file-uri (&rest args))
 (defun find-image (&rest args))
 (defun general-process-argument-editing-function (&rest args))
 (defun image-size (&rest args))
@@ -46,6 +60,9 @@
 (defun image-type-available-p (&rest args))
 (defun insert-image (&rest args))
 (defun jit-lock-register (&rest args))
+(defun mac-set-file-type (&rest args))
+(defun make-network-process (&rest args))
+(defun mouse-set-point (&rest args))
 (defun multibyte-string-p (&rest args))
 (defun mw32script-init (&rest args))
 (defun mw32script-make-pathext-regexp (&rest args))
@@ -60,6 +77,7 @@
 (defun string-as-unibyte (&rest args))
 (defun tool-bar-add-item-from-menu (&rest args))
 (defun tool-bar-local-item-from-menu (&rest args))
+(defun toolbar-button-help-string (&rest args))
 (defun update-coding-systems-internal (&rest args))
 (defun w32-focus-frame (&rest args))
 (defun w3m-expand-file-name-as-url (&rest args))
@@ -68,5 +86,3 @@
 (defun w3m-url-local-p (&rest args))
 (defun w3m-url-to-file-name (&rest args))
 (defun x-dnd-choose-type (&rest args))
-(defun dnd-get-local-file-name (&rest args))
-(defun dnd-get-local-file-uri (&rest args))
