@@ -7,7 +7,7 @@
 
 #include "mew.h"
 
-private char version_message[] = "version 4.2 20050107 Yasunari Momoi";
+private char version_message[] = "version 5.1 20050107 Yasunari Momoi";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -67,9 +67,12 @@ enum MBOXSTATE {
 #endif
 
 private char	FileBuf[FBUFSIZ];
-private char	InboxDir[PATH_MAX];
 private char	Mbox[PATH_MAX];
 private char	MboxLock[PATH_MAX];
+private char	*InboxDir = NULL;
+private char	*Suffix = NULL;
+private int	Use_Suffix = FALSE;
+private int	Suffix_len;
 private int	MboxType;
 private int	Backup;
 private int	GetCur;
@@ -90,10 +93,10 @@ private void	usage(const char *);
 private void	help(const char *);
 private void	version(const char *);
 private void	init_env(int, char **);
-private int	is_number(unsigned char *);
+private int	get_number(char *);
 private int	get_last_seq(void);
 private int	compare_string(char **, char **);
-private void	copyfile(char *, char *);
+private int	copyfile(char *, char *);
 private void	movefile(char *, char *, char *, int);
 private int	maildir_names(const char *, char **, char **, char **);
 private int	new_inbox_file(int, char[]);
@@ -164,20 +167,6 @@ Gethomedir(void)
 	return NULL;
 }
 
-#if !HAVE_STRDUP
-private char *
-strdup(const char *str)
-{
-	int len = strlen(str);
-	char* t;
-	MALLOC(t, len + 1);
-	if (t)
-		strncpy(t, len, str);
-	*(t + len) = NUL;
-	return t;
-}
-#endif
-
 private void
 error(const char *fmt, ...)
 {
@@ -209,7 +198,7 @@ error(const char *fmt, ...)
 
 private void
 usage(const char *progname) {
-	fprintf(stderr, "Usage: %s [-abchsv] [-d maildir] [-i inboxdir]\n", progname);
+	fprintf(stderr, "Usage: %s [-abchosv] [-d maildir] [-i inboxdir] [-x suffix]\n", progname);
 }
 
 private const char *
@@ -229,6 +218,8 @@ help_message[] = {
 	"    -u            Don't create inboxdir/.mew-mtime file.",
 	"    -f            Preserve Unix From (Envelope Sender). (for mbox)",
 	"    -p <fmode>    Specify file permission. (for mbox)",
+	"    -o		   Use the suffix when creating messages.",
+	"    -x <suffix>   Use this suffix.",
 	NULL
 };
 
@@ -350,21 +341,34 @@ private void
 init_env(int argc, char **argv)
 {
 	set_sighandler();
-	snprintf(InboxDir, sizeof(InboxDir), ".");
+	STRDUP(InboxDir, ".");
 	MboxType = T_UNKNOWN;
 	Backup = FALSE;
 	UseCL = FALSE;
 	search_mbox_path();
+	STRDUP(Suffix, SUFFIX);
+	Suffix_len = strlen(Suffix);
 }
 
 private int
-is_number(unsigned char *str)
+get_number(char *s)
 {
-	do {
-		if (!isdigit(*str))
-			return FALSE;
-	} while (*++str != '\0');
-	return TRUE;
+	int num = 0;
+	unsigned char c;
+
+	while ((c = *s) != NUL && isdigit(c)) {
+		num = num * 10 + c - '0';
+		s++;
+	}
+
+	if (num == 0)
+		return 0;
+	else if (*s == NUL)
+		return num;
+	else if (strncmp(s, Suffix, Suffix_len) == 0 && s[Suffix_len] == NUL)
+		return num;
+	else
+		return 0;
 }
 
 private int
@@ -378,9 +382,8 @@ get_last_seq(void)
 	if ((dirp = opendir(InboxDir)) == NULL)
 		error("opendir(%s)", InboxDir);
 	while ((dp = readdir(dirp)) != NULL) {
-		if (!is_number(dp->d_name))
+		if ((seq = get_number(dp->d_name)) == 0)
 			continue;
-		seq = atoi(dp->d_name);
 		last = last > seq ? last : seq;
 	}
 	closedir(dirp);
@@ -393,7 +396,7 @@ compare_string(char **i, char **j)
 	return strcmp(*i, *j);
 }
 
-private void
+private int
 copyfile(char *src, char *dst)
 {
 	struct timeval tv[2];
@@ -409,14 +412,16 @@ copyfile(char *src, char *dst)
 		error("open(%s) for write", dst);
 	while ((rlen = read(srcfd, FileBuf, FBUFSIZ)) > 0) {
 		if ((wlen = write(dstfd, FileBuf, rlen)) != rlen) {
-			close(dstfd);
+			if (close(dstfd))
+				goto werr;
 			unlink(dst);
 			error("write(%s) (read %d bytes/write %d bytes)",
 			      dst, rlen, wlen);
 		}
 	}
 	if (rlen < 0) {
-		close(dstfd);
+		if (close(dstfd))
+			goto werr;
 		unlink(dst);
 		error("read(%s)", src);
 	}
@@ -443,24 +448,32 @@ copyfile(char *src, char *dst)
 	if (chmod(dst, sb.st_mode))
 		warning("chmod(%s) failed", dst);
 #endif
+	return 0;
+
+ werr:
+	close(srcfd);
+	return -1;
 }
 
 private void
 movefile(char *fromfile, char *tofile, char *backupfile, int backup)
 {
 	if (backup && backupfile != NULL) {
-		copyfile(fromfile, tofile);
+		if (copyfile(fromfile, tofile))
+			error("copyfile(%s, %s)", fromfile, tofile);
 		if (rename(fromfile, backupfile))
 			error("rename(%s, %s)", fromfile, backupfile);
 	}
 	else if (backup) {
-		copyfile(fromfile, tofile);
+		if (copyfile(fromfile, tofile))
+			error("copyfile(%s, %s)", fromfile, tofile);
 	}
 	else {
 		if (rename(fromfile, tofile)) {
 			if (errno != EXDEV)
 				error("rename(%s, %s)", fromfile, tofile);
-			copyfile(fromfile, tofile);
+			if (copyfile(fromfile, tofile))
+				error("copyfile(%s, %s)", fromfile, tofile);
 			if (unlink(fromfile))
 				error("unlink(%s)", fromfile);
 		}
@@ -495,8 +508,10 @@ private int
 new_inbox_file(int seq, char inboxfile[])
 {
 	char num[PATH_MAX];
+	char *suffix = (Use_Suffix == YES) ? Suffix : "";
+
 	do {
-		snprintf(num, sizeof(num), "%d", ++seq);
+		snprintf(num, sizeof(num), "%d%s", ++seq, suffix);
 		if (strlen(InboxDir) + strlen(num) + 2 > PATH_MAX)
 			error("pathname too long (%s/%s)", InboxDir, num);
 		snprintf(inboxfile, PATH_MAX, "%s/%s", InboxDir, num);
@@ -514,9 +529,10 @@ open_new_inbox_file(int *seq, char inboxfile[])
 	int flag = O_EXCL | O_CREAT | O_WRONLY;
 	int fd;
 	FILE *fp = NULL;
+	char *suffix = (Use_Suffix == YES) ? Suffix : "";
 
 	for (;;) {
-		snprintf(num, sizeof(num), "%d", ++*seq);
+		snprintf(num, sizeof(num), "%d%s", ++*seq, suffix);
 		if (strlen(InboxDir) + strlen(num) + 2 > PATH_MAX)
 			error("pathname too long (%s/%s)", InboxDir, num);
 		snprintf(inboxfile, PATH_MAX, "%s/%s", InboxDir, num);
@@ -566,8 +582,7 @@ get_from_dir(int seq, char *fromdir, char *backupdir, int backup)
 			     realloc(list, sizeof(char *)*listsize)) == NULL)
 				error("realloc");
 		}
-		if ((list[listend++] = strdup(dp->d_name)) == NULL)
-			error("strdup(%s)", dp->d_name);
+		STRDUP(list[listend++], dp->d_name);
 	}
 	closedir(dirp);
 
@@ -671,7 +686,7 @@ process_mbox(int seq)
 		warning("fdopen(%s) for read", Mbox);  goto rerr;
 	}
 
-	while ((ln = getline(srcfp)) != NULL) {
+	while ((ln = Getline(srcfp)) != NULL) {
 		if (Exit)
 			goto werr;
 		switch (state) {
@@ -709,7 +724,8 @@ process_mbox(int seq)
 			break;
 		case ST_BODY_AFTER_EMPTY_LINE:
 			if (bytes < 0 && strncmp(ln, "From ", 5) == 0) {
-				fclose(dstfp);
+				if (fclose(dstfp))
+					goto rerr;
 				printf("%d\n", seq);
 
 				dstfp = open_new_inbox_file(&seq, inboxfile);
@@ -740,7 +756,9 @@ process_mbox(int seq)
 			if (bytes >= 0) {
 				bytes -= strlen(ln);
 				if (bytes <= 0) {
-					fclose(dstfp);  dstfp = NULL;
+					if (fclose(dstfp))
+						goto rerr;
+					dstfp = NULL;
 					printf("%d\n", seq);
 					state = ST_UNKNOWN;
 					bytes = -1;
@@ -752,7 +770,8 @@ process_mbox(int seq)
 		free(ln);
 	}
 	if (dstfp) {
-		fclose(dstfp);
+		if (fclose(dstfp))
+			goto rerr;
 		printf("%d\n", seq);
 	}
 	if (!Backup && ftruncate(srcfd, 0)) {
@@ -786,7 +805,7 @@ process_stdin(int seq)
 	if ((dstfp = open_new_inbox_file(&seq, inboxfile)) == NULL)
 		goto rerr;
 
-	while ((ln = getline(srcfp)) != NULL) {
+	while ((ln = Getline(srcfp)) != NULL) {
 		if (Exit)
 			goto werr;
 		if (fputs(ln, dstfp) == EOF) {
@@ -878,7 +897,7 @@ main(int argc, char **argv)
 	warn_prog = progname;
 	init_env(argc, argv);
 
-	while ((ch = Getopt(argc, argv, "abcd:fhi:m:p:suv")) != EOF) {
+	while ((ch = Getopt(argc, argv, "abcd:fhi:m:op:suvx:")) != EOF) {
 		switch (ch) {
 		case 'a':
 			GetCur = TRUE;
@@ -899,9 +918,14 @@ main(int argc, char **argv)
 			PreserveUnixFrom = TRUE;
 			break;
 		case 'i':
-			if (strlen(Optarg) + 1 > PATH_MAX)
-				error("pathname too long (%s)", Optarg);
-			snprintf(InboxDir, sizeof(InboxDir), "%s", Optarg);
+			STRDUP(InboxDir, Optarg);
+			break;
+		case 'o':
+			Use_Suffix = TRUE;
+			break;
+		case 'x':
+			STRDUP(Suffix, Optarg);
+			Suffix_len = strlen(Suffix);
 			break;
 		case 'p':
 			sscanf(Optarg, "%i", &FileMode);
