@@ -9,7 +9,7 @@
 
 #include "mew.h"
 
-private char version_message[] = "version 4.2 20050107 Kazu Yamamoto";
+private char version_message[] = "version 5.1 20060327 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 # include <sys/types.h>
@@ -91,6 +91,7 @@ struct fld_rng {
 
 private char Buf_header[MAX_HEADER];
 private char Buf_filenm[MAX_FILE_NAME_LEN];
+private char Buf_filenm2[MAX_FILE_NAME_LEN];
 private char *Mail_home;
 private char Current_folder[MAX_FILE_NAME_LEN];
 private struct fld_rng Folders[MAX_FOLDER];
@@ -100,11 +101,14 @@ private char *Key_field = NULL;
 private char *Exec_cmd = NULL;
 private char *Exec_arg = NULL;
 private char *Input_file = NULL;
+private char *Suffix = NULL;
+private char *Suffix_fmt = NULL;
 
 private int All_fields = 0;
 private int Field_len = MAX_FIELD_LEN;
 private int Body_len = MAX_BODY_LEN;
 private int PrintNumOfMsg = NO;
+private int Suffix_len = 0;
 
 /****************************************************************
  *
@@ -167,6 +171,7 @@ help_message[] = {
 	" -s  <src>     Message source: '+folder range'.",
 	" -w            Wait for stdio input to synchronize.",
 	" -v            Display the version.",
+	" -x            Use this suffix.",
 	"",
 	"<range> = N | [start]-[end] | last:N", 
 	"<pattern> = 'key=val' | 'key!=val' | '!<pattern>' | '(<pattern>)' ",
@@ -686,22 +691,27 @@ private unsigned int *Scan_ctx_buf;
 
 private int
 scan_numfile(char *s, unsigned int first, unsigned int last) {
-	unsigned int num = 0;
+	int num = 0;
+	unsigned char c;
 
-	if (*s == NUL)
-		return 0;
-
-	while (*s != NUL) {
-		if (!isdigit((unsigned char)*s))
-			return 0;
-		num = num * 10 + *s - '0';
+	while ((c = *s) != NUL && isdigit(c)) {
+		num = num * 10 + c - '0';
 		s++;
 	}
 
-	if (num >= first && (last == 0 || num <= last))
-		return 1;
+	if (num == 0)
+		return FALSE;
+	else if (*s == NUL)
+		;
+	else if (strncmp(s, Suffix, Suffix_len) == 0 && s[Suffix_len] == NUL)
+		;
 	else
-		return 0;
+		return FALSE;
+
+	if (num >= first && (last == 0 || num <= last))
+		return TRUE;
+        else
+                return FALSE;
 }
 
 private int
@@ -785,19 +795,24 @@ scan_getfile(char **filename, char **foldername)
 					    
 	while (i < Scan_ctx_messages) {
 		snprintf(Buf_filenm, sizeof(Buf_filenm), "%d", *(Scan_ctx_buf + i));
-		fp = fopen(Buf_filenm, FDREAD);
-		if (fp == NULL) {
-			/* for invalid cache messages */
-			snprintf(Buf_filenm, sizeof(Buf_filenm), "0%d", *(Scan_ctx_buf + i));
-			fp = fopen(Buf_filenm, FDREAD);
-			if (fp == NULL) {
-			  i++;
-			  continue;
-			}
+		snprintf(Buf_filenm2, sizeof(Buf_filenm2), Suffix_fmt, "", *(Scan_ctx_buf + i));
+		fp = fopen(Buf_filenm2, FDREAD);
+		if (fp == NULL) fp = fopen(Buf_filenm, FDREAD);
+		if (fp != NULL) {
+			i++;
+			*filename = Buf_filenm;
+			return fp;
+		}
+		snprintf(Buf_filenm, sizeof(Buf_filenm), "0%d", *(Scan_ctx_buf + i));
+		snprintf(Buf_filenm2, sizeof(Buf_filenm2), Suffix_fmt, "0", *(Scan_ctx_buf + i));
+		fp = fopen(Buf_filenm2, FDREAD);
+		if (fp == NULL) fp = fopen(Buf_filenm, FDREAD);
+		if (fp != NULL) {
+			i++;
+			*filename = Buf_filenm;
+			return fp;
 		}
-		*filename = Buf_filenm;
 		i++;
-		return fp;
 	}
 	goto again;
 }
@@ -895,9 +910,17 @@ exec_getfile(char **filename, char **foldername)
 		if (isdigit((unsigned char)*p) == 0) continue;
 		*filename = p;
 		while (isdigit((unsigned char)*p)) p++;
+		if (STRCMP(p, Suffix)==0)
+			p = p + Suffix_len;
 		*p = NUL;
 		fp = fopen(*filename, FDREAD);
 		if (fp != NULL) return fp;
+		/* incm? */
+		if (strlen(*filename) + Suffix_len >= sizeof(Buf_filenm))
+			warn_exit("file name is too long.");
+		strncat(p, Suffix, Suffix_len);
+		fp = fopen(*filename, FDREAD);
+		if (fp != NULL) return fp;
 	}
 	return NULL;
 }
@@ -983,7 +1006,7 @@ main(int argc, char **argv)
 	warn_prog = progname;
 	STRDUP(Mail_home, MAILHOME);
 
-	while ((optc = Getopt(argc, argv, "ab:c:d:e:f:hi:l:m:np:s:vw")) != EOF) {
+	while ((optc = Getopt(argc, argv, "ab:c:d:e:f:hi:l:m:np:s:vwx:")) != EOF) {
 		switch (optc) {
 		case 'a':
 			All_fields++;
@@ -1038,6 +1061,9 @@ main(int argc, char **argv)
 		case 'w':
 			wflag++;
 			break;
+		case 'x':
+			STRDUP(Suffix, Optarg);
+			break;
 		default:
 			usage(progname);
 			exit(EXIT_FAILURE);
@@ -1046,6 +1072,12 @@ main(int argc, char **argv)
 
 	rest = argc - Optind;
 
+	/* Suffix */
+	if (Suffix == NULL) STRDUP(Suffix, SUFFIX);
+	Suffix_len = strlen(Suffix);
+	MALLOC(Suffix_fmt, (Suffix_len + 10)); /* xxx */
+	snprintf(Suffix_fmt, Suffix_len + 10, "%%s%%d%s", Suffix);
+
 	if (sflag == 0) 
 		switch (rest) { /* lim == 0 */
 		case 0:
