@@ -367,39 +367,34 @@ returned."
 executed with '\\[universal-argument]', it will add personal information.  Otherwise,
 it will add an alias."
   (interactive "P")
-  (mew-summary-display nil)
   (let ((fld (mew-summary-folder-name))
 	(msg (mew-summary-message-number2))
-	(buf (mew-buffer-message))
 	from shortname addrs name)
     (save-excursion
-      (set-buffer buf)
-      (unless (mew-msghder-p)
-	(setq buf (mew-cache-hit fld msg 'must-hit))
-	(set-buffer buf))
-      (setq from (mew-header-get-value mew-from:))
-      (if (null from)
+      (mew-summary-set-message-buffer fld msg)
+      (setq from (mew-header-get-value mew-from:)))
+    (if (null from)
+	(message "No address to be registered")
+      ;; assuming From: contains just one address
+      (setq addrs (mew-addrstr-parse-address from))
+      (if (mew-is-my-address mew-regex-my-address-list addrs)
+	  (if personalinfo
+	      (setq addrs (car (mew-header-parse-address-list
+				(list mew-to:))))
+	    (setq addrs (mapconcat 'identity
+				   (mew-header-parse-address-list
+				    (list mew-to: mew-cc:))
+				   ",")))
+	(when (string-match "\\(.*\\)<.*>" from)
+	  (setq name (match-string 1 from))
+	  (setq name (mew-chop name)))
+	(if mew-addrbook-strip-domainpart
+	    (setq shortname (downcase (mew-addrstr-extract-user addrs)))
+	  (setq shortname (downcase addrs))))
+      (if (not addrs)
 	  (message "No address to be registered")
-	;; assuming From: contains just one address
-	(setq addrs (mew-addrstr-parse-address from))
- 	(if (mew-is-my-address mew-regex-my-address-list addrs)
- 	    (if personalinfo
- 		(setq addrs (car (mew-header-parse-address-list
- 				  (list mew-to:))))
-	      (setq addrs (mapconcat 'identity
-				     (mew-header-parse-address-list
-				      (list mew-to: mew-cc:))
-				     ",")))
- 	  (when (string-match "\\(.*\\)<.*>" from)
-	    (setq name (match-string 1 from))
-	    (setq name (mew-chop name)))
- 	  (if mew-addrbook-strip-domainpart
- 	      (setq shortname (downcase (mew-addrstr-extract-user addrs)))
- 	    (setq shortname (downcase addrs))))
- 	(if (not addrs)
- 	    (message "No address to be registered")
- 	  (mew-addrbook-prepare-template
-	   personalinfo shortname addrs nil name))))))
+	(mew-addrbook-prepare-template
+	 personalinfo shortname addrs nil name)))))
 
 (defun mew-addrbook-prepare-template (personalinfop shortname addrs &optional nickname name)
   (delete-other-windows)
@@ -568,7 +563,7 @@ reflected."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2005 Mew developing team.
+;; Copyright (C) 1999-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
