@@ -149,10 +149,10 @@ attachments region.
 	  (goto-char (1- (mew-attach-begin)))
 	  (re-search-forward "^..... " nil t)
 	  (mew-attach-move-onto-file))
-      (setq numreg (int-to-string (car nums)))
+      (setq numreg (number-to-string (car nums)))
       (setq nums (cdr nums))
       (while nums
-	(setq numreg (concat (int-to-string (car nums)) "." numreg))
+	(setq numreg (concat (number-to-string (car nums)) "." numreg))
 	(setq nums (cdr nums)))
       (setq numreg (regexp-quote numreg))
       (goto-char (1+ (mew-attach-begin)))
@@ -310,7 +310,8 @@ attachments region.
 (defun mew-attach-duplicate (func action setmode &optional from to default)
   (if (not (mew-attach-not-line012-1))
       (message "Cannot %s here" action)
-    (let* ((nums (mew-syntax-nums))
+    (let* ((completion-ignored-extensions nil)
+	   (nums (mew-syntax-nums))
 	   (subdir (mew-attach-expand-path mew-encode-syntax nums))
 	   (attachdir (mew-attachdir))
 	   (frompath from)
@@ -390,10 +391,11 @@ To copy a remote file, use the \"/[user@]hostname:/filepath\" syntax."
   "Link the message displayed in Message mode with a symbolic link
 on '.' in attachments."
   (interactive)
-  (let ((fld (mew-current-get-fld (mew-frame-id)))
-	(msg (mew-current-get-msg (mew-frame-id)))
-	default)
-    (if fld (setq default (mew-expand-folder fld msg)))
+  (let* ((fid (mew-frame-id))
+	 (fld (mew-current-get-fld fid))
+	 (msg (mew-current-get-msg fid))
+	 default)
+    (if fld (setq default (mew-expand-msg fld msg)))
     (if mew-use-symbolic-link-for-forwarding
 	(mew-attach-duplicate 'mew-symbolic-link "link" nil nil nil default)
       (mew-attach-duplicate 'copy-file "copy" nil nil nil default))))
@@ -688,6 +690,29 @@ Input decryptors' addresses."
 	(mew-syntax-set-decrypters syntax towhom)
 	(mew-encode-syntax-print mew-encode-syntax)))))))
 
+(defun mew-attach-smime-sign ()
+  "Put the 'PS' mark to sign with S/MIME in attachments."
+  (interactive)
+  (cond
+   ((not (mew-attach-not-line0-1-dot))
+    (message "Cannot S/MIME sign here"))
+   ((null mew-smime-ver)
+    (message "%s does not exist" mew-prog-smime))
+   (t
+    (let* ((nums (mew-syntax-nums))
+	   (syntax (mew-syntax-get-entry mew-encode-syntax nums))
+	   (privacy (mew-syntax-get-privacy syntax))
+	   (smime-sign (mew-pcdb-ct (mew-pcdb-by-service 'smime-signature))))
+      (cond
+       ((>= (length privacy) 2)
+	(message "Too many marks"))
+       ((member (car smime-sign) privacy) ;; xxx hard coding
+	(message "Already marked"))
+       (t
+	(mew-syntax-set-privacy 
+	 syntax (append privacy smime-sign))
+	(mew-encode-syntax-print mew-encode-syntax)))))))
+
 ;;
 ;; find commands
 ;;
@@ -711,11 +736,49 @@ Input decryptors' addresses."
       (if (file-symlink-p FILE)
 	  (message "This file is a symbolic link. Take care")))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;
+;; Drag & Drop
+;;
+
+(defun mew-draft-dnd-test-function (window action types)
+  (let ((type (x-dnd-choose-type types)))
+    (if type
+	(cons action type)
+      nil)))
+
+(defun mew-draft-dnd-handle-local-file (uri action)
+  (let* ((from (dnd-get-local-file-name uri t))
+	 (to (file-name-nondirectory from)))
+    (when from
+      (unless (mew-attach-p)
+	(mew-draft-prepare-attachments))
+      (goto-char (point-max))
+      (forward-line -2)
+      (mew-attach-next)
+      (cond
+       ((file-directory-p from)
+	(message "Directory cannot be attached"))
+       ((or (eq action 'copy)
+	    (eq action 'private)
+	    (eq action 'move))
+	(mew-attach-copy from to))
+       ((eq action 'link)
+	(mew-attach-link from to))
+       (t 
+	(message "Nothing happened"))))))
+
+(defun mew-draft-dnd-handle-file (uri action)
+  (let ((local-file (dnd-get-local-file-uri uri)))
+    (if local-file
+	(mew-draft-dnd-handle-local-file local-file action)
+      nil)))
+
 (provide 'mew-attach)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
