@@ -11,22 +11,28 @@
   '(("B" . mew-base64-encode-string)
     ("Q" . mew-q-encode-string)))
 
-(defvar mew-header-decode-switch
-  '(("B" . mew-base64-decode-string)
-    ("Q" . mew-q-decode-string)))
-
-(defvar mew-header-decode-error-switch
-  `(("B" . ,mew-error-invalid-b-encoding)
-    ("Q" . ,mew-error-invalid-q-encoding)))
-
 (defsubst mew-header-encode-get-func (b-or-q)
   (cdr (mew-assoc-case-equal b-or-q mew-header-encode-switch 0)))
 
+
+(defvar mew-header-decode-switch
+  `(("B"
+     mew-base64-decode-string
+     mew-base64-decode-error-string
+     ,mew-error-invalid-b-encoding)
+    ("Q"
+     mew-q-decode-string
+     nil
+     ,mew-error-invalid-q-encoding)))
+
 (defsubst mew-header-decode-get-func (b-or-q)
-  (cdr (mew-assoc-case-equal b-or-q mew-header-decode-switch 0)))
+  (nth 1 (mew-assoc-case-equal b-or-q mew-header-decode-switch 0)))
+
+(defsubst mew-header-decode-get-error-func (b-or-q)
+  (nth 2 (mew-assoc-case-equal b-or-q mew-header-decode-switch 0)))
 
 (defsubst mew-header-decode-get-error-str (b-or-q)
-  (cdr (mew-assoc-case-equal b-or-q mew-header-decode-error-switch 0)))
+  (nth 3 (mew-assoc-case-equal b-or-q mew-header-decode-switch 0)))
 
 (defconst mew-header-decode-regex
   "=\\?\\([^? \t]+\\)\\?\\(.\\)\\?\\([^? \t]+\\)\\?=")
@@ -81,7 +87,7 @@
   (let* ((estr (mew-cs-encode-string str hcs)))
     (concat "=?" charset "?" b-or-q "?" (funcall fun estr) "?=")))
 
-(defun mew-header-decode (charset b-or-q estr)
+(defun mew-header-decode (charset b-or-q estr &optional key)
   (let* ((fun (mew-header-decode-get-func b-or-q))
 	 (cs (mew-charset-to-cs charset))
 	 str)
@@ -93,6 +99,7 @@
       mew-error-unknown-charset)
      (fun ;; if cs is nil, mew-cs-decode-string does not cs-decode.
       (setq str (funcall fun estr))
+      (unless str (setq str (mew-header-decode-error key b-or-q estr)))
       (if (null str)
 	  (mew-header-decode-get-error-str b-or-q)
 	(when (and mew-decode-broken
@@ -107,6 +114,28 @@
 	  (mew-cs-decode-string str cs))))
      (t estr))))
 
+(defun mew-header-decode-error (key b-or-q estr)
+  (let ((func (mew-header-decode-get-error-func b-or-q)))
+    (if func (funcall func key b-or-q estr))))
+
+(defun mew-base64-decode-error-string (key b-or-q estr)
+  (let ((str estr) strlen r ret)
+    (when (string-match "^\\([^=]*\\)=*$" str)
+      (setq str (mew-match-string 1 str)))
+    (setq strlen (length str))
+    (setq r (% strlen 4))
+    (cond
+     ((= r 0)
+      (setq ret (mew-base64-decode-string str)))
+     ((= r 1)
+      )
+     ((= r 2)
+      (setq ret (mew-base64-decode-string (concat str "=="))))
+     ((= r 3)
+      (setq ret (mew-base64-decode-string (concat str "=")))))
+    (if ret (mew-decode-warning-fields key 'padding))
+    ret))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Quoted-printable encoding
@@ -610,7 +639,8 @@
 	(end (match-end 0))
 	(css (mew-header-decode (mew-match-string 1)
 				(mew-match-string 2)
-				(mew-match-string 3))))
+				(mew-match-string 3)
+				key)))
     (setq css (mew-header-sanity-check-string2 css key))
     (delete-region beg end)
     (insert css)))
@@ -650,6 +680,9 @@
        ((eq err 'raw)
 	(setq level 2)
 	(setq wmsg (concat key " has raw text strings.\n")))
+       ((eq err 'padding)
+	(setq level 2)
+	(setq wmsg (concat key " has illegal padding in encoded text.\n")))
        ((eq err 'quoted)
 	(setq level 2)
 	(setq wmsg (concat key " has encoded-words in quoted text.\n"))))
@@ -887,7 +920,7 @@ That is, each line may be more than 75."
 	  (if asterisk
 	      (setq section 0)
 	    (setq section nil))
-	(setq section (string-to-int (substring section 1))))
+	(setq section (string-to-number (substring section 1))))
       (if (null asterisk)
 	  ;; delete quote
 	  (progn
@@ -942,7 +975,7 @@ That is, each line may be more than 75."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2005 Mew developing team.
+;; Copyright (C) 1997-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
