@@ -22,7 +22,7 @@ Mew -- Messaging in the Emacs World
 
 %s
 
-Copyright (C) 1994-2004 Kazu Yamamoto
+Copyright (C) 1994-2006 Kazu Yamamoto
 
 Please send comments to Kazu@Mew.org.
 
@@ -103,7 +103,8 @@ Please send comments to Kazu@Mew.org.
 	(center-region (point-min) (point-max))
 	(mew-redraw time))
        (t
-	(mew-hello-text time))))))
+	(mew-hello-text time)))
+      (set-buffer-modified-p nil))))
 
 (defun mew-hello-text (time)
   (insert "/\\\\ - \\\\/")
@@ -141,7 +142,7 @@ Please send comments to Kazu@Mew.org.
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
