@@ -24,7 +24,7 @@
   `((,mew-ct-pge mew-pgp-encrypt)))
 
 (defvar mew-encode-multipart-signed-switch
-  `((,mew-ct-pgs mew-pgp-sign)
+  `((,mew-ct-pgs mew-pgp-sign mew-pgp-canonicalize)
     (,mew-ct-sms mew-smime-sign)))
 
 ;;
@@ -32,6 +32,9 @@
 (defsubst mew-encode-get-security-func (proto switch)
   (nth 1 (mew-assoc-case-equal proto switch 0)))
 
+(defsubst mew-encode-get-canonicalize-func (proto switch)
+  (nth 2 (mew-assoc-case-equal proto switch 0)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; MIME encoder
@@ -178,8 +181,8 @@
 	    (setq val (mew-buffer-substring start (1- (point))))
 	    (delete-region start (1- (point)))
 	    (backward-char 1)
-	    ;;
-	    (setq vals (mapcar 'mew-chop (mew-split-quoted val ?, ?: ?\;)))
+	    ;; single quote is allowed for local-part
+	    (setq vals (mapcar 'mew-chop (mew-split-quoted val ?, ?: ?\; 'no-single)))
 	    (while vals
 	      (setq val (car vals))
 	      (setq vals (cdr vals))
@@ -368,6 +371,10 @@
 	(error
 	 (mew-encode-undo)
 	 (message "%s" (mew-tinfo-get-encode-err))
+	 (setq ret nil))
+	(quit
+	 (mew-encode-undo)
+	 (message "quit")
 	 (setq ret nil))))
     ret))
 
@@ -403,7 +410,7 @@
       (mew-encode-error (format "'%s' is not in the right form!" recipients))))
     ;; Header modifications which are not remained.
     (mew-header-delete-lines (list mew-fcc: mew-resent-fcc:)) ;; anyway
-    (mew-smtp-set-dcc pnm (mew-encode-delete-dcc resentp))
+    (mew-encode-delete-dcc resentp)
     (mew-smtp-set-bcc pnm (mew-encode-delete-bcc resentp))
     (mew-smtp-set-fcc pnm fcc)
     ;;
@@ -444,6 +451,10 @@
 	(error
 	 (mew-encode-undo)
 	 (message "%s" (mew-tinfo-get-encode-err))
+	 (setq ret nil))
+	(quit
+	 (mew-encode-undo)
+	 (message "quit")
 	 (setq ret nil))))
     ret))
 
@@ -522,6 +533,12 @@
   ;; Only parts to be signed FIRST are limited to 7bit.
   (and privacy (mew-case-equal mew-ct-mls (car (car privacy)))))
 
+(defvar mew-encode-max-line-length 990)
+;; RFC 2822 defines 1000 but Sendmail uses 990
+
+(defvar mew-ask-encoding t)
+(defvar mew-default-encoding mew-b64)
+
 (defun mew-encode-mime-body (ctl cte file)
   ;; If file is 't', target is buffered.
   ;; text should be buffered
@@ -536,7 +553,7 @@
                      mew-prog-mime-encode-text-switch
                    mew-prog-mime-encode-switch))
          (beg (point))
-	 buffer cs opt)
+	 buffer cs opt last)
     (if (and (stringp file)
 	     (setq buffer (get-file-buffer file))
 	     (buffer-modified-p buffer))
@@ -578,14 +595,29 @@
 	    (setq cte (mew-charset-to-cte charset)))
 	(if (or (null cte) (mew-case-equal cte mew-bin))
 	    ;; unknown charset
-	    (setq cte mew-b64))
+	    (setq cte mew-default-encoding))
 	(cond
 	 (mew-inherit-7bit
 	  (if (mew-case-equal cte mew-8bit)
-	      (setq cte mew-b64)))
+	      (setq cte mew-default-encoding)))
 	 (mew-use-8bit
 	  (if (mew-encode-charset-8bitp charset)
-	      (setq cte mew-8bit)))))))
+	      (setq cte mew-8bit))))
+	(when (or (mew-case-equal cte mew-7bit) (mew-case-equal cte mew-8bit))
+	  (save-excursion
+	    (goto-char beg)
+	    (mew-set-buffer-multibyte nil)
+	    (catch 'long-line
+	      (while t
+		(setq last (point))
+		(if (/= (forward-line) 0) (end-of-line))
+		(when (>= (- (point) last) mew-encode-max-line-length) ;; including LF
+		  (if (not mew-ask-encoding)
+		      (setq cte mew-default-encoding)
+		    (setq cte (mew-input-encoding)))
+		  (throw 'long-line nil))
+		(if (eobp) (throw 'long-line nil))))
+	    (mew-set-buffer-multibyte t))))))
      ((string= ct mew-ct-msg)
       (if (mew-encode-file-8bitp file)
 	  (setq cte mew-8bit)
@@ -759,7 +791,7 @@
 (defun mew-encode-multipart (syntax path depth &optional buffered)
   (let* ((boundary
 	  (mew-boundary-get ;; 0 is nil for Next_Part
-	   (if (> depth 0) (format "BOUNDARY%s" (int-to-string depth)))))
+	   (if (> depth 0) (format "BOUNDARY%s" (number-to-string depth)))))
 	 (fullname (expand-file-name (mew-syntax-get-file syntax) path))
 	 (ctl (mew-syntax-get-ct syntax))
 	 (ct (mew-syntax-get-value ctl 'cap))
@@ -824,7 +856,7 @@
 
 (defun mew-security-multipart-boundary (depth)
    (if depth
-       (mew-boundary-get (format "Security_Multipart%s" (int-to-string depth)))
+       (mew-boundary-get (format "Security_Multipart%s" (number-to-string depth)))
      (mew-boundary-get "Security_Multipart")))
 
 (defun mew-save-transfer-form (beg end retain)
@@ -904,7 +936,9 @@
   (let* ((boundary (mew-security-multipart-boundary depth))
 	 (switch mew-encode-multipart-signed-switch) ;; save length
 	 (func (mew-encode-get-security-func proto switch))
+	 (canon-func (mew-encode-get-canonicalize-func proto switch))
 	 file1 file2 micalg cte2 fmc errmsg ct2 cdp2)
+    (if (fboundp canon-func) (funcall canon-func))
     (setq file1 (mew-save-transfer-form (point-min) (point-max) 'retain))
     ;; The narrowed region still the ORIGINAL part (i.e. line breaks are LF)
     ;; Call the protocol function
@@ -1000,7 +1034,7 @@
       (goto-char hd-end)
       (mew-header-insert mew-mv: (concat mew-mv:-num " " mew-field-comment)))
      (t
-      (goto-char (marker-position hd-end))
+      (goto-char hd-end)
       (forward-line)
       (setq body-beg (point))
       (setq body-end (point-max))
@@ -1179,7 +1213,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2005 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
