@@ -106,7 +106,7 @@ DELS represents the messages to be deleted."
   (let ((suffix (mew-folder-suffix src))
 	file infofile)
     (while dels
-      (setq file (mew-expand-folder src (car dels)))
+      (setq file (mew-expand-msg src (car dels)))
       (setq dels (cdr dels))
       ;; if file does not exist, the marked line will be deleted anyway.
       (mew-delete-file file)
@@ -116,8 +116,8 @@ DELS represents the messages to be deleted."
 
 (defun mew-i2s (num cache)
   (if cache
-      (concat "0" (int-to-string num)) ;; "0" is the mark for invalid messages
-    (int-to-string num)))
+      (concat "0" (number-to-string num)) ;; "0" is the mark for invalid messages
+    (number-to-string num)))
 
 (defun mew-summary-mv-msgs (src dsts-msgs)
   (let* ((dsts (car dsts-msgs)) ;; (+foo +bar)
@@ -134,20 +134,20 @@ DELS represents the messages to be deleted."
 	  (while msgs
 	    (setq msg (car msgs))
 	    (setq msgs (cdr msgs))
-	    (if (file-regular-p (mew-expand-folder src msg))
+	    (if (file-regular-p (mew-expand-msg src msg))
 		(setq msgs- (cons msg msgs-))))
 	  (setq msgs- (nreverse msgs-))
 	  (setq msgs msgs-))
       (setq dst (mew-case-folder mew-inherit-exec-case (car dsts)))
       (setq dsts (cdr dsts))
-      (setq num (string-to-int (mew-folder-new-message dst 'num-only cache)))
+      (setq num (string-to-number (mew-folder-new-message dst 'num-only cache)))
       (while msgs
-	(setq srcfile (mew-expand-folder src (car msgs)))
+	(setq srcfile (mew-expand-msg src (car msgs)))
 	(setq msgs (cdr msgs))
 	(when (and (file-exists-p srcfile) (file-writable-p srcfile))
 	  (setq strnum (mew-i2s num cache))
 	  (setq msgs- (cons strnum msgs-))
-	  (setq dstfile (mew-expand-folder dst strnum))
+	  (setq dstfile (mew-expand-new-msg dst strnum))
 	  (setq num (1+ num))
 	  (rename-file srcfile dstfile 'override)
 	  (when suffix
@@ -159,13 +159,13 @@ DELS represents the messages to be deleted."
     (while dsts
       (setq dst (mew-case-folder mew-inherit-exec-case (car dsts)))
       (setq dsts (cdr dsts))
-      (setq num (string-to-int (mew-folder-new-message dst 'num-only cache)))
+      (setq num (string-to-number (mew-folder-new-message dst 'num-only cache)))
       (setq msgs msgs-)
       (while msgs
-	(setq srcfile (mew-expand-folder src (car msgs)))
+	(setq srcfile (mew-expand-msg src (car msgs)))
 	(setq msgs (cdr msgs))
 	(setq strnum (mew-i2s num cache))
-	(setq dstfile (mew-expand-folder dst strnum))
+	(setq dstfile (mew-expand-new-msg dst strnum))
 	(setq num (1+ num))
 	(mew-link srcfile dstfile))
       (mew-touch-folder dst))))
@@ -177,12 +177,12 @@ DELS represents the messages to be deleted."
 	 (suffix (mew-folder-suffix src))
 	 num srcfile dstfile infofile)
     (unless (file-directory-p trashdir) (make-directory trashdir))
-    (setq num (string-to-int (mew-folder-new-message trash 'num-only cache)))
+    (setq num (string-to-number (mew-folder-new-message trash 'num-only cache)))
     ;; must be here after ensuring that +trash exists.
     (while dels
-      (setq srcfile (mew-expand-folder src (car dels))) ;; xxx
+      (setq srcfile (mew-expand-msg src (car dels))) ;; xxx
       (setq dels (cdr dels))
-      (setq dstfile (mew-expand-folder trash (mew-i2s num cache)))
+      (setq dstfile (mew-expand-new-msg trash (mew-i2s num cache)))
       (setq num (1+ num))
       (if (file-regular-p srcfile)
 	  ;; if not, the marked line will be deleted anyway.
@@ -269,13 +269,9 @@ destination is the same as that of the current message are processed."
 ;;; Exec region
 ;;;
 
-(defun mew-summary-move-and-display (msg)
-  (let ((here (point)))
-    (goto-char (point-min))
-    (if (not (re-search-forward (mew-regex-sumsyn-msg msg) nil t))
-	(goto-char here)
-      (beginning-of-line)
-      (mew-summary-display nil))))
+(defun mew-summary-move-and-display (msg &optional redisplay)
+  (when (mew-summary-search-msg msg)
+    (mew-summary-display redisplay)))
 
 (defun mew-summary-go-back-summary (key)
   (let ((msg (mew-summary-message-number))
@@ -340,11 +336,10 @@ destination is the same as that of the current message are processed."
 	  (let* ((marks (mew-mark-get-all-marks))
 		 (src (mew-summary-folder-name 'ext))
 		 (lbuf (mew-refile-log-buffer src))
-		 (m (make-marker))
+		 (m (copy-marker end))
 		 (cnt 0)
 		 (case-fold-search nil)
 		 msg msgs err-folders mark func-exec func-sanity killp regex)
-	    (set-marker m end)
 	    (while marks
 	      (setq mark (car marks))
 	      (setq marks (cdr marks))
@@ -409,7 +404,10 @@ destination is the same as that of the current message are processed."
     (beginning-of-line)
     (setq start (point))
     (forward-line)
-    (mew-elet (put-text-property start (point) 'invisible t))))
+    (mew-elet
+     (put-text-property start (point) 'invisible t)
+     ;; For Emacs only. To make invisible text act as we want
+     (put-text-property start (point) 'front-sticky t))))
 
 (defun mew-summary-exec-remote-get-info (beg end modify)
   ;; for POP or IMAP
@@ -419,7 +417,7 @@ destination is the same as that of the current message are processed."
   ;; by mew-summary-exec-local().
   (let* ((case (mew-sinfo-get-case))
 	 (folder (mew-sinfo-get-folder))
-	 (m (make-marker))
+	 (m (copy-marker end))
 	 trash trash-list lomov
 	 siz msg uid ref flds del regex trss rmvs kils refs movs
 	 refinfo refile-back mark rttl dttl)
@@ -439,7 +437,6 @@ destination is the same as that of the current message are processed."
 	(if (string= folder trash)
 	    (setq trash nil)))))
     (save-excursion
-      (set-marker m end)
       (mew-decode-syntax-delete)
       (setq regex (mew-mark-regex mew-mark-refile))
       (goto-char beg)
@@ -517,6 +514,8 @@ destination is the same as that of the current message are processed."
 	(if (not info)
 	    (message "No messages to be processed")
 	  (mew-summary-reset)
+	  (while (eq (get-text-property (point) 'invisible) t)
+	    (forward-line))
 	  (cond
 	   ((mew-folder-popp folder)
 	    (mew-pop-retrieve case 'exec bnm info))
@@ -637,7 +636,7 @@ the queue, type '\\[mew-summary-send-message]' in the queue online."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2005 Mew developing team.
+;; Copyright (C) 1997-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
