@@ -31,14 +31,27 @@
   (memq major-mode '(mew-draft-mode mew-header-mode)))
 
 (defsubst mew-thread-p ()
-  (mew-vinfo-get-thread-p))
+  (mew-vinfo-get-parent-folder))
 
 (defsubst mew-summary-or-virtual-p ()
   (or (mew-summary-p) (mew-virtual-p)))
 
+(defsubst mew-virtual-for-one-summary ()
+  (and (mew-virtual-p) (= (length (mew-vinfo-get-flds)) 1)))
+
 (defsubst mew-pickable-p ()
   (or (mew-summary-p)
-      (and (mew-virtual-p) (= (length (mew-vinfo-get-flds)) 1))))
+      (mew-thread-p)
+      (mew-virtual-for-one-summary)))
+
+(defsubst mew-pickable-folder ()
+  (cond
+   ((mew-summary-p)
+    (mew-summary-folder-name 'ext))
+   ((mew-thread-p)
+    (mew-vinfo-get-parent-folder))
+   ((mew-virtual-for-one-summary)
+    (car (mew-vinfo-get-flds)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -51,9 +64,9 @@
 (defun mew-folder-recursive-match (key folder)
   "Initial substring match for folders.
 If FOLDER is a sub-folder of KEY or KEY itself, t is returned."
-  ;; file-name-as-directory should be first because
-  ;; the path separator may be regex-non-safe.
-  (let ((regex (if (string-match "^[+-=%]+$" key)
+  ;; file-name-as-directory should be first
+  ;; because the path separator may be regex-non-safe.
+  (let ((regex (if (string-match "^[-+%$]$" key)
 		   (mew-folder-regex key)
 		 (mew-folder-regex (file-name-as-directory key)))))
     (string-match regex (file-name-as-directory folder))))
@@ -352,7 +365,7 @@ Words are separated by '/' and '-'."
       (insert str))))
 
 (defsubst mew-insert-message (fld msg rcs size)
-  (let ((file (mew-expand-folder fld msg)))
+  (let ((file (mew-expand-msg fld msg)))
     (cond
      ((not (file-readable-p file))
       (error "%s does not exist" (mew-concat-folder fld msg)))
@@ -392,33 +405,49 @@ Words are separated by '/' and '-'."
 	(setq ret (cons (substring str start) ret)))
     (nreverse ret)))
 
-(defun mew-split-quoted (str sepchar &optional qopen qclose)
+(defun mew-remove-single-quote (str)
+  (let* ((len (length str))
+	 (ret (make-string len mew-sp))
+	 (i 0) (j 0))
+    (while (< i len)
+      (unless (char-equal (aref str i) ?')
+	(aset ret j (aref str i))
+	(setq j (1+ j)))
+      (setq i (1+ i)))
+    (substring ret 0 j)))
+
+(defun mew-split-quoted (str sepchar &optional qopen qclose no-single)
   "Return a list of strings splitting STR with SEPCHAR.
 SEPCHARs in double-quoted strings are ignored.
 If QUOTEDCHAR is provided, SEPCHARs between QOPEN and QCLOSE are
 also ignored."
- (let ((qlevel 0) (len (length str)) (start 0) (i 0) dblq ret c)
-   (if (and qopen (not qclose)) (setq qclose qopen))
-   (while (< i len)
-     (setq c (aref str i))
-     (cond 
-      ((char-equal ?\\ c)
-       (setq i (1+ i)))
-      ((char-equal ?\" c)
-       (setq dblq (not dblq)))
-      ((and qopen (char-equal c qopen))
-       (setq qlevel (1+ qlevel)))
-      ((and qclose (char-equal c qclose))
-       (setq qlevel (1- qlevel)))
-      ((char-equal c sepchar)
-       (if (or dblq (>= qlevel 1))
-	   ()
-	 (setq ret (cons (substring str start i) ret))
-	 (setq start (1+ i)))))
-     (setq i (1+ i)))
-   (if (/= start len)
-       (setq ret (cons (substring str start) ret)))
-   (nreverse ret)))
+  (let ((qlevel 0) (len (length str)) (start 0) (i 0) dblq sub ret c)
+    (if (and qopen (not qclose)) (setq qclose qopen))
+    (while (< i len)
+      (setq c (aref str i))
+      (cond 
+       ((char-equal ?\\ c)
+	(setq i (1+ i)))
+       ((or (char-equal ?\" c) (and (not no-single) (char-equal ?' c)))
+	(setq dblq (not dblq)))
+       ((and qopen (char-equal c qopen))
+	(setq qlevel (1+ qlevel)))
+       ((and qclose (char-equal c qclose))
+	(setq qlevel (1- qlevel)))
+       ((char-equal c sepchar)
+	(unless (or dblq (>= qlevel 1))
+	  (setq sub (substring str start i))
+	  (unless no-single
+	    (setq sub (mew-remove-single-quote sub)))
+	  (setq ret (cons sub ret))
+	  (setq start (1+ i)))))
+      (setq i (1+ i)))
+    (when (/= start len)
+      (setq sub (substring str start))
+      (unless no-single
+	(setq sub (mew-remove-single-quote sub)))
+      (setq ret (cons sub ret)))
+    (nreverse ret)))
 
 (defun mew-chop (str)
   "Split off preceding and following white spaces."
@@ -543,9 +572,20 @@ If case is \"default\", it is not prepended."
 
 ;;
 
+(defun mew-summary-physical-folder ()
+  (cond
+   ((mew-thread-p)
+    (mew-vinfo-get-parent-folder))
+   ((mew-virtual-for-one-summary)
+    (car (mew-vinfo-get-flds)))
+   (t
+    (mew-summary-folder-name 'ext))))
+
+;;
+
 (defsubst mew-local-to-dir (folder)
   (if (string-match "^[+]" folder)
-      (substring folder 1 nil)
+      (substring folder 1)
     folder))
 
 ;;
@@ -630,10 +670,12 @@ If case is \"default\", it is not prepended."
       (mew-concat-folder (mew-nntp-folder case) subdir))
      ((mew-folder-imapp folder)
       (mew-concat-folder (mew-imap-folder case)
-			 (mew-imap-expand-folder case subdir)))
+			 (mew-imap-expand-folder
+			  case
+			  (mew-imap-utf-7-encode-string subdir))))
      (t folder))))
 
-(defun mew-expand-folder (folder &optional message)
+(defun mew-expand-folder (folder)
   "Expanding FOLDER to its absolute path"
   (when (stringp folder)
     (let (dir)
@@ -643,9 +685,35 @@ If case is \"default\", it is not prepended."
 	;; absolute path
 	;; "C:/" -> t, "C:" -> nil , "CC:/" -> nil
 	(setq dir (expand-file-name folder)))
-      (if message
-	  (expand-file-name message dir)
-	dir))))
+      dir)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Suffix support
+;;;
+
+(defvar mew-use-suffix nil)
+
+(defun mew-msg-new-filename (file)
+  (if mew-use-suffix
+      (format "%s%s" file mew-suffix)
+    file))
+
+(defun mew-msg-get-filename (file)
+  (let ((sfile (format "%s%s" file mew-suffix)))
+    (if (file-exists-p sfile)
+	sfile
+      file)))
+
+(defun mew-expand-msg (folder message)
+  (let ((file (expand-file-name message (mew-expand-folder folder))))
+    (mew-msg-get-filename file)))
+
+(defun mew-expand-new-msg (folder message)
+  (mew-msg-new-filename (expand-file-name message (mew-expand-folder folder))))
+
+(defun mew-expand-file (folder file)
+  (expand-file-name file (mew-expand-folder folder)))
 
 (defun mew-concat-folder (folder subfolder)
   (concat (file-name-as-directory folder) subfolder))
@@ -655,7 +723,7 @@ If case is \"default\", it is not prepended."
       (concat (mew-imap-file-name-as-directory folder case) subfolder)
     (concat (file-name-as-directory folder) subfolder)))
 
-(defsubst mew-dir-messages (dir &optional regex)
+(defsubst mew-dir-messages (dir &optional regex full)
   ;; directory_files uses ENCODE_FILE() for DIR and
   ;;                      DECODE_FILE() for results(FILES).
   ;; Both ENCODE_FILE() and DECODE_FILE() are quite slow.
@@ -673,15 +741,15 @@ If case is \"default\", it is not prepended."
     (setq edir (mew-cs-encode-string edir cs))
     (or regex (setq regex mew-regex-message-files))
     (mew-alet
-     (directory-files edir nil regex 'no-sort))))
+     (directory-files edir full regex 'no-sort))))
 
 (defun mew-folder-messages (folder)
   (let* ((dir (mew-expand-folder folder))
 	 msgs nums)
     (when (file-directory-p dir)
       (setq msgs (mew-dir-messages dir))
-      (setq nums (sort (mapcar 'string-to-int msgs) '<))
-      (mapcar 'int-to-string nums))))
+      (setq nums (sort (mapcar 'string-to-number msgs) '<))
+      (mapcar 'number-to-string nums))))
 
 (defun mew-folder-new-message (folder &optional num-only cache)
   (let* ((dir (mew-expand-folder folder))
@@ -692,12 +760,12 @@ If case is \"default\", it is not prepended."
     (when (file-directory-p dir)
       (setq msgs (mew-dir-messages dir regex))
       (while msgs
-	(setq cur (string-to-int (car msgs)))
+	(setq cur (string-to-number (file-name-sans-extension (car msgs))))
 	(if (> cur max) (setq max cur))
 	(setq msgs (cdr msgs)))
       (setq max (1+ max))
-      (setq maxfile (int-to-string max))
-      (setq maxpath (mew-expand-folder folder maxfile))
+      (setq maxfile (number-to-string max))
+      (setq maxpath (mew-expand-new-msg folder maxfile))
       (while (file-exists-p maxpath) ;; xxx
 	;; If NFS is used, readdir() may fail. Emacs 20 does not
 	;; rescan the directory again. So, we need to rescan in
@@ -706,29 +774,29 @@ If case is \"default\", it is not prepended."
 	(setq msgs (mew-dir-messages dir regex))
 	(setq max 0)
 	(while msgs
-	  (setq cur (string-to-int (car msgs)))
+	  (setq cur (string-to-number (file-name-sans-extension (car msgs))))
 	  (if (> cur max) (setq max cur))
 	  (setq msgs (cdr msgs)))
 	(setq max (1+ max))
-	(setq maxfile (int-to-string max))
-	(setq maxpath (mew-expand-folder folder maxfile)))
+	(setq maxfile (number-to-string max))
+	(setq maxpath (mew-expand-new-msg folder maxfile)))
       (while (get-file-buffer maxpath) ;; xxx
 	;; file not exist but there is a buffer.
 	(setq max (1+ max))
-	(setq maxfile (int-to-string max))
-	(setq maxpath (mew-expand-folder folder maxfile)))
+	(setq maxfile (number-to-string max))
+	(setq maxpath (mew-expand-new-msg folder maxfile)))
       (while (file-exists-p maxpath)
 	(setq maxfile (read-string (format "%s/%s exists. Input a message number: " max folder)))
 	(while (not (string-match mew-regex-message-files maxfile))
 	  (setq maxfile (read-string "Input NUMBER: ")))
-	(setq maxpath (mew-expand-folder folder maxfile)))
+	(setq maxpath (mew-expand-new-msg folder maxfile)))
       (if num-only
-	  maxfile
+	  (mew-msg-new-filename maxfile)
 	maxpath))))
 
 (defun mew-touch-folder (fld)
   (when (stringp mew-summary-touch-file)
-    (let ((file (mew-expand-folder fld mew-summary-touch-file)))
+    (let ((file (mew-expand-file fld mew-summary-touch-file)))
       (when (file-writable-p file)
 	(write-region "touched by Mew." nil file nil 'no-msg)
 	(mew-set-file-modes file)))))
@@ -859,9 +927,16 @@ If case is \"default\", it is not prepended."
   (or (mew-which (concat elfile ".el") load-path)
       (mew-which (concat elfile ".elc") load-path)))
 
+(defvar mew-which-exec-suffixes '(""))
+
 (defun mew-which-exec (execfile)
-  (or (mew-which execfile exec-path)
-      (mew-which (concat execfile ".exe") exec-path)))
+  (let ((suffixes mew-which-exec-suffixes)
+	file)
+    (catch 'detect
+      (while suffixes
+	(when (setq file (mew-which (concat execfile (car suffixes)) exec-path))
+	  (throw 'detect file))
+	(setq suffixes (cdr suffixes))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -931,11 +1006,13 @@ Does not examine containing directories for links."
       (substring file 2)
     file))
 
-(defun mew-set-file-modes (path)
+(defun mew-get-file-modes (path)
   (let* ((dir (file-name-directory path))
-	 (dirmode (mew-file-get-mode dir))
-	 (mode (logand dirmode mew-file-mode-mask)))
-    (set-file-modes path mode)))
+	 (dirmode (mew-file-get-mode dir)))
+    (logand dirmode mew-file-mode-mask)))
+
+(defun mew-set-file-modes (path)
+  (set-file-modes path (mew-get-file-modes path)))
 
 (defun mew-delete-file (file)
   (if (and (stringp file) (file-exists-p file)) (delete-file file)))
@@ -1140,7 +1217,8 @@ and sets buffer-file-coding-system."
 
 (defmacro mew-filter (&rest body)
   `(let ((pbuf (process-buffer process)) ;; MUST use 'process'
-	 (obuf (buffer-name)))
+	 (obuf (buffer-name))
+	 (inhibit-eol-conversion nil)) ;; \r\n as is
      (if (and (bufferp pbuf)
 	      (buffer-name pbuf)) ;; check a killed buffer
 	 ;; must use buffer-name instead of current-buffer
@@ -1379,23 +1457,23 @@ by side-effect."
   "\\([0-9]+\\)[ \t]+\\([a-zA-Z]+\\)[ \t]+\\([0-9]+\\)[ \t]+\\([0-9]+\\):\\([0-9]+\\)\\(:\\([0-9]+\\)\\)?\\([ \t]+\\([-+0-9a-zA-Z]+\\)\\)?")
 
 (defmacro mew-time-rfc-day  ()
-  '(string-to-int (substring s (match-beginning 1) (match-end 1))))
+  '(string-to-number (substring s (match-beginning 1) (match-end 1))))
 
 (defmacro mew-time-rfc-mon  ()
   '(substring s (match-beginning 2) (match-end 2)))
 
 (defmacro mew-time-rfc-year ()
-  '(string-to-int (substring s (match-beginning 3) (match-end 3))))
+  '(string-to-number (substring s (match-beginning 3) (match-end 3))))
 
 (defmacro mew-time-rfc-hour ()
-  '(string-to-int (substring s (match-beginning 4) (match-end 4))))
+  '(string-to-number (substring s (match-beginning 4) (match-end 4))))
 
 (defmacro mew-time-rfc-min  ()
-  '(string-to-int (substring s (match-beginning 5) (match-end 5))))
+  '(string-to-number (substring s (match-beginning 5) (match-end 5))))
 
 (defmacro mew-time-rfc-sec  ()
   '(if (match-beginning 7)
-       (string-to-int (substring s (match-beginning 7) (match-end 7)))
+       (string-to-number (substring s (match-beginning 7) (match-end 7)))
      0))
 
 ;; returns seconds
@@ -1405,7 +1483,7 @@ by side-effect."
 	     int)
 	 (cond
 	  ((string-match "^[-+][0-9]+$" tmzn)
-	   (setq int (string-to-int tmzn))
+	   (setq int (string-to-number tmzn))
 	   (+ (* (/ int 100) 3600) (* (% int 100) 60)))
 	  ((setq int (mew-time-tmzn-str-to-int tmzn))
 	   (* int 3600))
@@ -1515,7 +1593,7 @@ by side-effect."
 
 (defsubst mew-port-sanity-check (port)
   (if (string-match "^[0-9]+$" port)
-      (string-to-int port)
+      (string-to-number port)
     port))
 
 (defsubst mew-dot-insert ()
@@ -1582,7 +1660,7 @@ by side-effect."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2003 Mew developing team.
+;; Copyright (C) 1997-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
