@@ -353,6 +353,8 @@
 	   ((char-equal c ?\t))
 	   ((char-equal c mew-sp))
 	   ((char-equal c sep)
+	    ;; broken quoted string cannot be rescued because
+	    ;; the separator cannot be distinguished
 	    (if (> tmp-cnt 0)
 		(setq ret (cons (substring tmp 0 tmp-cnt) ret)))
 	    (setq tmp-cnt 0)
@@ -361,8 +363,13 @@
 	    (aset tmp tmp-cnt c)
 	    (setq tmp-cnt (1+ tmp-cnt)))) ;; end of cond
 	  (setq i (1+ i)))		  ;; end of while
-	(if (> tmp-cnt 0)
-	    (setq ret (cons (substring tmp 0 tmp-cnt) ret)))) ;; end of catch
+	(when (> tmp-cnt 0)
+	  ;; broken quoted string can be rescued if it appears solely
+	  (save-match-data
+	    (if (string-match "<\\([^>]+\\)>" tmp)
+		(setq ret (cons (mew-match-string 1 tmp) ret))
+	      (setq ret (cons (substring tmp 0 tmp-cnt) ret)))))) ;; end of catch
+      (setq ret (delete nil ret))
       (if (featurep 'mew-temacs)
 	  (mapcar 'string-as-multibyte (nreverse ret)) ;; A bug of Emacs 20.7
 	(nreverse ret)))))
@@ -484,7 +491,7 @@ Remove anonymous addresses."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2005 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
