@@ -160,7 +160,7 @@
 	   ((eq directive 'copy)
 	    (setq src-file msg))
 	   (t
-	    (setq src-file (mew-expand-folder (mew-case-folder case src) msg))))
+	    (setq src-file (mew-expand-msg (mew-case-folder case src) msg))))
 	  (mew-frwlet
 	   mew-cs-text-for-read mew-cs-dummy
 	   (set-buffer (mew-find-file-noselect src-file)))
@@ -366,7 +366,7 @@
 	pro tm)
     (condition-case emsg
 	(progn
-	  (setq tm (mew-timer mew-imap-timeout-time 'mew-imap2-timeout))
+	  (setq tm (run-at-time mew-imap-timeout-time nil 'mew-imap2-timeout))
 	  (message "Connecting to the IMAP server...")
 	  (setq pro (open-network-stream pnm nil server sprt))
 	  (process-kill-without-query pro)
@@ -413,7 +413,7 @@
 	(setq sslname (process-name sslpro))
 	(setq lport (mew-ssl-pnm-to-lport sslname))
 	(when lport
-	  (setq process (mew-imap2-open pnm "localhost" lport)))))
+	  (setq process (mew-imap2-open pnm mew-ssl-localhost lport)))))
      (t
       (setq process (mew-imap2-open pnm server port))))
     (if (null process)
@@ -481,7 +481,7 @@ time (even several days) if there are many local messages."
   (mew-summary-not-in-draft
    (let* ((fld (mew-summary-folder-name))
 	  (msg (mew-summary-message-number))
-	  (fld/msg (mew-expand-folder fld msg))
+	  (fld/msg (mew-expand-msg fld msg))
 	  (src-list (list fld/msg))
 	  (case:dst (mew-input-folder mew-case mew-imap-inbox-folder))
 	  (case (mew-case:folder-case case:dst))
@@ -513,7 +513,7 @@ with '*' in the region are handled."
      (if (null msgs)
 	 (message "No mark")
        (when (mew-folder-imapp dst)
-	 (setq src-list (mapcar (lambda (x) (mew-expand-folder fld x)) msgs))
+	 (setq src-list (mapcar (lambda (x) (mew-expand-msg fld x)) msgs))
 	 (mew-imap2-copy-message case 'copy src-list dst))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -618,8 +618,8 @@ with '*' in the region are handled."
       (setq src (car srcs))
       (setq srcs (cdr srcs))
       (setq dst (mew-i2s i 'cache))
-      (copy-file (mew-expand-folder case:srcfld src)
-		 (mew-expand-folder case:dstfld dst))
+      (copy-file (mew-expand-msg case:srcfld src)
+		 (mew-expand-new-msg case:dstfld dst))
       (setq i (1+ i)))
     (mew-touch-folder case:dstfld)))
 
@@ -627,7 +627,7 @@ with '*' in the region are handled."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2003 Mew developing team.
+;; Copyright (C) 2003-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
