@@ -35,9 +35,9 @@
 ;;; Net folders
 ;;;
 
-(defvar mew-pop-folder  "+.pop/%s@%s%%%s")
-(defvar mew-imap-folder "+.imap/%s@%s%%%s")
-(defvar mew-nntp-folder "+.nntp/%s@%s%%%s")
+(defvar mew-pop-folder  "+#pop/%s@%s#%s")
+(defvar mew-imap-folder "+#imap/%s@%s#%s")
+(defvar mew-nntp-folder "+#nntp/%s@%s#%s")
 
 (defun mew-pop-folder (&optional case)
   (format mew-pop-folder
@@ -70,7 +70,7 @@
   (force-mode-line-update))
 
 (defun mew-net-status-clear (buf)
-  (when mew-use-net-status
+  (when (and mew-use-net-status buf (get-buffer buf))
     (save-excursion
       (set-buffer buf)
       (setq mew-summary-buffer-process-status nil)
@@ -97,7 +97,7 @@
 (defun mew-net-status2 (buf rttl rcnt siz &optional zero secure)
   (when mew-use-net-status
     (when (<= rcnt rttl)
-      (let ((msiz (string-to-int siz))
+      (let ((msiz (string-to-number siz))
 	    (bsiz (if zero 0 (buffer-size)))
 	    percent substatus)
 	(if (and (numberp mew-net-status-percent-size)
@@ -153,7 +153,7 @@
   (setq mew-biff-string nil))
 
 (defun mew-biff-setup ()
-  (let ((inbox (mew-proto-inbox-folder nil mew-case-input))
+  (let ((inbox (mew-proto-inbox-folder nil mew-case))
 	func)
     (if (not mew-use-biff)
 	(mew-biff-clean-up)
@@ -235,18 +235,19 @@
 
 (defun mew-net-get-new-message (pnm bnm msg get set)
   (if msg
-      (cons msg (mew-expand-folder bnm msg)) ;; 'get
+      (cons msg (mew-expand-msg bnm msg)) ;; 'get
     (let ((msg (funcall get pnm))
 	  file nxt)
       (cond
        (msg
-	(setq nxt (int-to-string (1+ (string-to-int msg))))
+	(setq nxt (number-to-string (1+ (string-to-number msg))))
 	(funcall set pnm nxt)
-	(setq file (mew-expand-folder bnm msg)))
+	(setq file (mew-expand-new-msg bnm msg)))
        (t
 	(setq file (mew-folder-new-message bnm))
-	(setq msg (file-name-nondirectory file))
-	(setq nxt (int-to-string (1+ (string-to-int msg))))
+	;; 1.eml => 1
+	(setq msg (file-name-sans-extension (file-name-nondirectory file)))
+	(setq nxt (number-to-string (1+ (string-to-number msg))))
 	(funcall set pnm nxt)))
       (cons msg file))))
 
@@ -259,8 +260,9 @@
   (if (not (file-exists-p (concat file mew-queue-work-suffix)))
       file
     (let* ((dir (file-name-directory file))
-	   (num (file-name-nondirectory file))
-	   (n (1+ (string-to-int num))))
+	   ;; 1.eml => 1
+	   (num (file-name-sans-extension (file-name-nondirectory file)))
+	   (n (1+ (string-to-number num))))
       (while (or (file-exists-p (format "%s%d" dir n))
 		 (file-exists-p (format "%s%d%s" dir n mew-queue-work-suffix)))
 	(setq n (1+ n)))
@@ -296,7 +298,7 @@
     (rename-file iwrk info 'override)))
 
 (defun mew-queue-insert-file (pnm n qfld msg) ;; 1
-  (let* ((file (mew-expand-folder qfld msg))
+  (let* ((file (mew-expand-new-msg qfld msg))
 	 (work (concat file mew-queue-work-suffix)) ;; 1.wrk
 	 (info (concat file mew-queue-info-suffix)) ;; 1.mqi
 	 (iwrk (concat info mew-queue-work-suffix)) ;; 1.mqi.wrk
@@ -389,7 +391,8 @@
 	  (mew-mark-kill-line))))
     (when ulks
       (setq ulks (nreverse ulks))
-      (mew-mark-exec-delete bnm ulks)
+      (let ((mew-trash-folder nil))
+	(mew-mark-exec-delete bnm ulks))
       (mew-summary-folder-cache-save))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -441,40 +444,58 @@
       (mew-rendezvous mew-summary-buffer-process))))
 
 (defun mew-summary-retrieve (&optional no-flush)
-  "Retrieve messages to +inbox asynchronously according to
-'mew-mailbox-type'. 
-
+  "In local folders, retrieve messages to +inbox asynchronously 
+according to 'mew-mailbox-type' and 'mew-case'. 
 If 'mew-auto-flush-queue' is non-nil, +queue is flushed.
-If called with '\\[universal-argument]', +queue is not flushed."
+If called with '\\[universal-argument]', +queue is not flushed.
+
+In remote folders, visit an inbox folder and scan with 'update."
   (interactive "P")
-  (let* ((case mew-case-input)
-	 (dont (not (mew-use-retrieve case)))
-	 (inbox (mew-inbox-folder case))
-	 (dir (mew-expand-folder inbox))
-	 (mailbox (mew-mailbox-type case)))
-    (if dont
-	(message "This command is not allowed to use")
-      (unless (file-directory-p dir)
-	(mew-make-directory dir))
-      ;; for mew-summary-exchange-point.
-      (set-marker mew-summary-inbox-position (point) (current-buffer))
-      (mew-summary-switch-to-folder inbox)
-      ;; in the inbox
-      (when (mew-summary-exclusive-p)
-	(mew-summary-reset)
+  (let (proto case inbox case:inbox mailbox case:folder)
+    (cond
+     ((mew-virtual-p)
+      (cond
+       ((setq case:folder (or (mew-vinfo-get-parent-folder) ;; Thread
+			      (car (mew-vinfo-get-flds)))) ;; Virtual by "/"
+	(setq proto (mew-case:folder-folder case:folder))
+	(setq case (mew-case:folder-case case:folder)))
+       (t ;; Virtual by "k/"
+	(setq proto (mew-proto mew-case))
+	(setq case mew-case))))
+     (t
+      (setq proto (mew-sinfo-get-folder)) ;; folder is proto
+      (setq case (or (mew-sinfo-get-case) ;; remote
+		     mew-case)))) ;; local
+    (setq inbox (mew-proto-inbox-folder proto case))
+    (cond
+     ((mew-folder-remotep proto)
+      (setq case:inbox (mew-case-folder case inbox)))
+     (t ;; local
+      (setq case:inbox inbox)))
+    ;; for mew-summary-exchange-point.
+    (mew-sinfo-set-ret-pos (point))
+    (mew-summary-visit-folder case:inbox)
+    ;; in the inbox
+    (when (mew-summary-exclusive-p)
+      (cond
+       ((mew-folder-remotep inbox)
+	(mew-summary-ls nil 'goend 'update))
+       (t ;; local
 	;;
+	(mew-summary-reset)
 	(mew-summary-retrieve-gap inbox)
 	;;
 	(goto-char (point-max))
 	(mew-sinfo-set-start-point (point))
 	(mew-sinfo-set-direction 'down)
+	(setq mailbox (mew-mailbox-type case))
 	(cond
 	 ((eq mailbox 'pop)
 	  (mew-pop-retrieve case 'inc inbox (not no-flush)))
 	 ((eq mailbox 'imap)
 	  (mew-imap-retrieve case 'inc inbox (not no-flush)))
 	 ((eq mailbox 'mbox)
-	  (mew-mbox-retrieve case 'inc inbox (not no-flush))))))))
+	  (mew-mbox-retrieve case 'inc inbox (not no-flush)))))))))
 
 (defun mew-summary-scan-boot (proto case)
   ;; called by mew()
@@ -487,7 +508,7 @@ If called with '\\[universal-argument]', +queue is not flushed."
     (mew-summary-switch-to-folder case:inbox)
     ;; in the inbox
     ;; for mew-summary-exchange-point.
-    (set-marker mew-summary-inbox-position (point) (current-buffer))
+    (mew-sinfo-set-ret-pos (point))
     (when (mew-summary-exclusive-p)
       (mew-summary-reset)
       ;;
@@ -525,8 +546,11 @@ If called with '\\[universal-argument]', +queue is not flushed."
 	      (setq opts (list "-e" mbox-command "-m" mbox-command-arg))
 	    (setq dir (mew-expand-folder inbox))
 	    (setq mode (mew-get-file-modes dir))
-	    (setq opts (list "-e" mbox-command
-			     "-m" (format "%s -p %d" mbox-command-arg mode))))
+	    (if mew-use-suffix
+		(setq opts (list "-e" mbox-command
+				 "-m" (format "%s -o -p %d" mbox-command-arg mode)))
+	      (setq opts (list "-e" mbox-command
+			       "-m" (format "%s -p %d" mbox-command-arg mode)))))
 	(setq opts (list "-e" mbox-command)))
       (mew-local-retrieve 'inc inbox flush opts))))
 
@@ -535,64 +559,171 @@ If called with '\\[universal-argument]', +queue is not flushed."
 ;;; Retrieving truncated messages
 ;;;
 
+(defun mew-summary-get-inherit-case (fld msg)
+  (let ((buf (mew-cache-hit fld msg))
+	uid)
+    (if buf
+	(save-excursion
+	  (set-buffer buf)
+	  (setq uid (mew-header-get-value mew-x-mew-uidl:)))
+      (with-temp-buffer
+	(mew-insert-message fld msg mew-cs-text-for-read mew-header-reasonable-size)
+	(setq uid (mew-header-get-value mew-x-mew-uidl:))))
+    (mew-scan-uid-case uid)))
+
+(defun mew-net-thread-info (msgs)
+  (let ((virtual (mew-summary-folder-name 'ext))
+	(summary (mew-summary-folder-name)))
+    (list virtual summary msgs)))
+
+(defun mew-net-thread-info-get-virtual (thread-info)
+  (nth 0 thread-info))
+
+(defun mew-net-thread-info-get-summary (thread-info)
+  (nth 1 thread-info))
+
+(defun mew-net-thread-info-get-msg (thread-info)
+  (nth 2 thread-info))
+
+(defun mew-net-disp-info ()
+  (let* ((fid (mew-frame-id))
+	 (buf (current-buffer))
+	 (fld (mew-current-get-fld fid))
+	 (msg (mew-current-get-msg fid))
+	 (disp (mew-sinfo-get-disp-msg)))
+    (if disp (list fid buf fld msg))))
+
+(defun mew-net-disp-info-fid (disp-info)
+  (nth 0 disp-info))
+
+(defun mew-net-disp-info-buf (disp-info)
+  (nth 1 disp-info))
+
+(defun mew-net-disp-info-fld (disp-info)
+  (nth 2 disp-info))
+
+(defun mew-net-disp-info-msg (disp-info)
+  (nth 3 disp-info))
+
+(defun mew-net-disp-info-display (disp-info)
+  (when disp-info
+    (let ((fid (mew-net-disp-info-fid disp-info))
+	  (buf (mew-net-disp-info-buf disp-info))
+	  (fld (mew-net-disp-info-fld disp-info))
+	  (msg (mew-net-disp-info-msg disp-info))
+	  (nfid (mew-frame-id))
+	  m)
+      (when (and (equal fid nfid)
+		 (equal fld (mew-current-get-fld nfid)))
+	(save-excursion
+	  (set-buffer buf)
+	  (setq m (point-marker))
+	  (set-marker-insertion-type m t)
+	  (when (and (mew-sinfo-get-disp-msg)
+		     (equal msg (mew-current-get-msg nfid))
+		     (mew-summary-search-msg msg))
+	    ;; The message was truncated probaby because it's too large.
+	    (mew-summary-analyze-again))
+	  (goto-char m))))))
+
 (defun mew-summary-retrieve-message (&optional rev-del)
   "Retrieve the rest of a truncated('T') message.
 
-In a LOCAL folder: a method to retrieve the message is determined by
-'mew-input-case' and 'mew-mailbox-type'. If
-'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the message from
-the mailbox. When executed with '\\[universal-argument]',
+In a LOCAL folder: a method to retrieve the message is determined
+by 'mew-case' and 'mew-mailbox-type'. 
+If 'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the message
+from the mailbox. When executed with '\\[universal-argument]',
 'mew-pop-delete'/'mew-imap-delete' is considered reversed.
 
 In a REMOTE folder: case and protocol are determined by the folder.
 The message in the server side is always retained."
   (interactive "P")
-  (mew-summary-only
-   (mew-summary-msg
-    (when (mew-summary-exclusive-p)
-      (when (mew-sumsyn-match mew-regex-sumsyn-long)
-	(let* ((msg (mew-sumsyn-message-number))
-	       (uid (mew-sumsyn-message-uid))
-	       (siz (mew-sumsyn-message-size))
-	       (bnm (mew-summary-folder-name 'ext))
-	       (folder (mew-sinfo-get-folder))
-	       (case (mew-sinfo-get-case))
-	       del rtr rtrs mailbox)
-	  (when (mew-folder-localp folder)
-	    (setq case mew-case-input)
-	    (setq mailbox (mew-mailbox-type case))
-	    (cond
-	     ((eq mailbox 'pop)
-	      (setq del (eq (mew-pop-delete case) t)));; delete may be number
-	     ((eq mailbox 'imap)
-	      (setq del (eq (mew-imap-delete case) t))));; delete may be number
-	    (if rev-del (setq del (not del))))
-	  (setq rtr (list uid siz del (list bnm msg)))
-	  (setq rtrs (list rtr))
-	  (cond
-	   ((not rtrs)
-	    (message "No message to be retrieved"))
-	   ((not (mew-msg-validp msg))
-	    (message "No valid message to be retrieved"))
-	   ((mew-folder-localp folder)
-	    (cond
-	     ((eq mailbox 'pop)
-	      (mew-pop-retrieve case 'get bnm rtrs))
-	     ((eq mailbox 'imap)
-	      (mew-imap-retrieve case 'get bnm rtrs))))
-	   ((mew-folder-popp folder)
-	    (mew-pop-retrieve case 'get bnm rtrs))
-	   ((mew-folder-imapp folder)
-	    (mew-imap-retrieve case 'get bnm rtrs))
-	   ((mew-folder-nntpp folder)
-	    (mew-nntp-retrieve case 'get bnm rtrs)))))))))
+  (mew-summary-msg
+   (when (mew-sumsyn-match mew-regex-sumsyn-long)
+     (let* ((msg (mew-sumsyn-message-number))
+	    (uid (mew-sumsyn-message-uid))
+	    (siz (mew-sumsyn-message-size))
+	    (bnm (mew-summary-folder-name))
+	    (disp-info (mew-net-disp-info))
+	    (thread-info (if (mew-thread-p) (mew-net-thread-info (list msg))))
+	    folder case del rtr rtrs mailbox)
+       (save-excursion
+	 (set-buffer bnm)
+	 (when (mew-summary-exclusive-p)
+	   (setq folder (mew-sinfo-get-folder))
+	   (setq case (mew-sinfo-get-case))
+	   (when (mew-folder-localp folder)
+	     (setq case (or (mew-summary-get-inherit-case folder msg) mew-case))
+	     (setq mailbox (mew-mailbox-type case))
+	     (cond
+	      ((eq mailbox 'pop)
+	       (setq del (eq (mew-pop-delete case) t))) ;; delete may be number
+	      ((eq mailbox 'imap)
+	       (setq del (eq (mew-imap-delete case) t)))) ;; delete may be number
+	     (if rev-del (setq del (not del))))
+	   (when (and uid (not (string= uid "")))
+	     (setq rtr (list uid siz del (list bnm msg)))
+	     (setq rtrs (list rtr)))
+	   (cond
+	    ((not rtrs)
+	     (message "No message to be retrieved"))
+	    ((not (mew-msg-validp msg))
+	     (message "No valid message to be retrieved"))
+	    ((mew-folder-localp folder)
+	     (cond
+	      ((eq mailbox 'pop)
+	       (mew-pop-retrieve case 'get bnm rtrs thread-info disp-info))
+	      ((eq mailbox 'imap)
+	       (mew-imap-retrieve case 'get bnm rtrs thread-info disp-info))))
+	    ((mew-folder-popp folder)
+	     (mew-pop-retrieve case 'get bnm rtrs thread-info disp-info))
+	    ((mew-folder-imapp folder)
+	     (mew-imap-retrieve case 'get bnm rtrs thread-info disp-info))
+	    ((mew-folder-nntpp folder)
+	     (mew-nntp-retrieve case 'get bnm rtrs thread-info disp-info)))))))))
+
+(defun mew-summary-retrieve-message-for-thread (thread-info)
+  (let ((virtual (mew-net-thread-info-get-virtual thread-info))
+	(summary (mew-net-thread-info-get-summary thread-info))
+	(msgs    (mew-net-thread-info-get-msg     thread-info))
+	msg str start beg end idt-str level length)
+    (save-excursion
+      (while msgs
+	(setq msg (car msgs))
+	(setq msgs (cdr msgs))
+	(set-buffer summary)
+	;; Summary
+	(save-excursion
+	  (when (mew-summary-search-msg msg)
+	    (setq start (point))
+	    (forward-line)
+	    (setq str (buffer-substring start (point)))))
+	(set-buffer virtual)
+	;; Virtual
+	(save-excursion
+	  (when (mew-summary-search-msg msg)
+	    (setq start (point))
+	    (setq beg (mew-thread-next-property start))
+	    (setq level (mew-thread-get-property beg))
+	    (setq length (* mew-thread-indent-length level))
+	    (setq end (+ beg length))
+	    (setq idt-str (buffer-substring beg end))
+	    (forward-line)
+	    (mew-elet
+	     (delete-region start (point))
+	     (insert str)
+	     (goto-char beg)
+	     (if (= level 0) (setq end (1+ end)))
+	     (insert idt-str)
+	     (mew-thread-put-property beg end level)))))
+      (mew-summary-unlock))))
 
 (defun mew-summary-mark-retrieve-message (&optional rev-del)
   "Retrieve the rest of truncated('T') messages marked with '*'.
 
 In a LOCAL folder: a method to retrieve the messages is determined by
-'mew-input-case' and 'mew-mailbox-type'.  If
-'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the messages
+'mew-case' and 'mew-mailbox-type'.  
+If 'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the messages
 from the mailbox.  When executed with '\\[universal-argument]',
 'mew-pop-delete'/'mew-imap-delete' is considered reversed.
 
@@ -603,37 +734,57 @@ The messages in the server side is always retained."
    (let* ((bnm (mew-summary-folder-name 'ext))
 	  (folder (mew-sinfo-get-folder))
 	  (case (mew-sinfo-get-case))
-	  msg uid siz del rtr rtrs mailbox)
-     (when (mew-folder-localp folder)
-       (setq case mew-case-input)
-       (setq mailbox (mew-mailbox-type case))
-       (cond
-	((eq mailbox 'pop)
-	 (setq del (eq (mew-pop-delete case) t))) ;; delete may be number
-	((eq mailbox 'imap)
-	 (setq del (eq (mew-imap-delete case) t)))) ;; delete may be number
-       (if rev-del (setq del (not del))))
+	  msg uid siz del rtr rtrs case-rtrs mailbox)
      (save-excursion
        (goto-char (point-min))
-       (while (re-search-forward mew-regex-msg-review nil t)
-	 (when (mew-sumsyn-match mew-regex-sumsyn-long)
+       (if (mew-folder-localp folder)
+	   (let (tmp)
+	     (while (re-search-forward mew-regex-msg-review nil t)
+	       (when (mew-sumsyn-match mew-regex-sumsyn-long)
+		 (setq uid (mew-sumsyn-message-uid))
+		 (setq msg (mew-sumsyn-message-number))
+		 (setq siz (mew-sumsyn-message-size))
+		 (setq case (or (mew-summary-get-inherit-case folder msg) mew-case))
+		 (setq mailbox (mew-mailbox-type case))
+		 (when (and (mew-msg-validp msg) (mew-msg-truncatedp siz))
+		   (cond
+		    ((eq mailbox 'pop)
+		     (setq del (eq (mew-pop-delete case) t))) ;; delete may be number
+		    ((eq mailbox 'imap)
+		     (setq del (eq (mew-imap-delete case) t))))	;; delete may be number
+		   (if rev-del (setq del (not del)))
+		   (setq rtr (list uid siz del (list bnm msg)))
+		   (if (setq tmp (nth 2 (assoc case case-rtrs)))
+		       (nconc tmp (list rtr))
+		     (setq case-rtrs (cons (list case mailbox (list rtr)) case-rtrs))))
+		 (forward-line)))
+	     (setq case-rtrs (nreverse case-rtrs)))
+	 (while (re-search-forward mew-regex-msg-review nil t)
+	   (when (mew-sumsyn-match mew-regex-sumsyn-long)
 	   (setq uid (mew-sumsyn-message-uid))
 	   (setq msg (mew-sumsyn-message-number))
 	   (setq siz (mew-sumsyn-message-size))
 	   (when (and (mew-msg-validp msg) (mew-msg-truncatedp siz))
 	     (setq rtr (list uid siz del (list bnm msg)))
 	     (setq rtrs (cons rtr rtrs))))
-	 (forward-line)))
-     (if (not rtrs)
+	   (forward-line))
+	 (setq rtrs (nreverse rtrs))))
+     (if (and (not rtrs) (not case-rtrs))
 	 (message "No message to be retrieved")
-       (setq rtrs (nreverse rtrs))
        (cond
 	((mew-folder-localp folder)
-	 (cond
-	  ((eq mailbox 'pop)
-	   (mew-pop-retrieve case 'get bnm rtrs))
-	  ((eq mailbox 'imap)
-	   (mew-imap-retrieve case 'get bnm rtrs))))
+	 (while case-rtrs
+	   (setq case (nth 0 (car case-rtrs)))
+	   (setq mailbox (nth 1 (car case-rtrs)))
+	   (setq rtrs (nth 2 (car case-rtrs)))
+	   (setq case-rtrs (cdr case-rtrs))
+	   (cond
+	    ((eq mailbox 'pop)
+	     (mew-pop-retrieve case 'get bnm rtrs))
+	    ((eq mailbox 'imap)
+	     (mew-imap-retrieve case 'get bnm rtrs)))
+	   (when case-rtrs
+	     (mew-rendezvous mew-summary-buffer-process))))
 	((mew-folder-popp folder)
 	 (mew-pop-retrieve case 'get bnm rtrs))
 	((mew-folder-imapp folder)
@@ -662,10 +813,10 @@ The messages in the server side is always retained."
   ;; => ("1" "3:5" "7:8" "10")
   (let (pack a b s)
     (when (setq a (car msgs))
-      (setq a (string-to-int a))
+      (setq a (string-to-number a))
       (setq msgs (cdr msgs))
       (while (setq b (car msgs))
-	(setq b (string-to-int b))
+	(setq b (string-to-number b))
 	(setq msgs (cdr msgs))
 	(if (= (1+ a) b)
 	    (if (null s)
@@ -703,7 +854,7 @@ The messages in the server side is always retained."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2002-2005 Mew developing team.
+;; Copyright (C) 2002-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
