@@ -29,7 +29,8 @@
     "user" "account"
     "size" "get-body" "no-msg" "case" "msgdb" "done" "dispatched" "error"
     "max"
-    "newsgroup" "msgid" "truncated"))
+    "newsgroup" "msgid" "truncated"
+    "thread-info" "disp-info" "status-buf"))
 
 (mew-info-defun "mew-nntp-" mew-nntp-info-list)
 
@@ -68,7 +69,7 @@
   (or (mew-nntp-get-ssh-process pnm) (mew-nntp-get-ssl-process pnm)))
 
 (defun mew-nntp-command-mode-reader (pro pnm)
-  (mew-net-status (mew-nntp-get-bnm pnm)
+  (mew-net-status (mew-nntp-get-status-buf pnm)
 		  "Connecting"
 		  nil
 		  (mew-nntp-secure-p pnm))
@@ -106,29 +107,35 @@
 	(refs (mew-nntp-get-refs pnm)) ;; (uid siz del (+fld msg))
 	(bnm (mew-nntp-get-bnm pnm))
 	(range (mew-nntp-get-range pnm))
-	max)
+	max first last)
     (if (and mew-nntp-skip-uidl (eq directive 'get))
 	(mew-nntp-command-dispatch pro pnm directive refs nil)
-      (mew-net-status bnm "Checking" nil (mew-nntp-secure-p pnm))
+      (mew-net-status (mew-nntp-get-status-buf pnm)
+		      "Checking" nil (mew-nntp-secure-p pnm))
       (cond
        ((eq directive 'scan)
 	(if (eq range nil) ;; update
 	    (setq max (mew-lisp-load
-		       (mew-expand-folder bnm mew-nntp-msgid-file))))))
-      (if (re-search-forward "^[0-9]+ +[0-9]+ +\\([0-9]+\\) +[0-9]+ +[-.a-zA-Z0-9]+" nil t)
+		       (mew-expand-file bnm mew-nntp-msgid-file))))))
+      ;; 221 total first last newsgroup (xxx)
+      (if (re-search-forward "^[0-9]+ +[0-9]+ +\\([0-9]+\\) +\\([0-9]+\\) +[-.a-zA-Z0-9]+" nil t)
 	  (progn
+	    (setq first (string-to-number (mew-match-string 1)))
+	    (setq last (string-to-number (mew-match-string 2)))
 	    (cond
 	     ((stringp max)
-	      (setq max (string-to-int max)))
+	      (setq max (1+ (string-to-number max))))
 	     (max ;; backward compatibility
 	      ;; reversed
 	      (setq max (car max))
-	      (setq max (string-to-int max)))
+	      (setq max (1+ (string-to-number max))))
+	     ((and (eq directive 'scan) (numberp range))
+	      (setq max (1+ (- last range)))
+	      (if (< max first) (setq max first)))
 	     (t
-	      (setq max (string-to-int (mew-match-string 1)))
-	      (setq max (1- max))))
+	      (setq max first)))
 	    (mew-nntp-set-max pnm max)
-	    (mew-nntp-process-send-string pro "XOVER %d-" (1+ max)))
+	    (mew-nntp-process-send-string pro "XOVER %d-" max))
 	(mew-nntp-set-status pnm "quit")
 	(mew-nntp-command-quit pro pnm)))))
 
@@ -151,15 +158,15 @@
 	(if rtr (setq rtrs (cons rtr rtrs))))
        ((eq directive 'scan)
 	(if (and uid (or range ;; all, last:n
-			 (> (string-to-int uid) max))) ;; update
+			 (> (string-to-number uid) max))) ;; update
 	    (setq rtrs (cons (list uid siz) rtrs))))
        ((eq directive 'sync)
 	(if uid (setq hlds (cons uid hlds))))))
     (mew-nntp-set-msgid pnm (nth 0 (car rtrs))) ;; 'scan
-    ;; last:n
-    (when (and (eq directive 'scan) (numberp range))
-      (if (> (length rtrs) range)
-	  (setcdr (nthcdr (1- range) rtrs) nil)))
+    ;; last:n xxx
+;;    (when (and (eq directive 'scan) (numberp range))
+;;      (if (> (length rtrs) range)
+;;	  (setcdr (nthcdr (1- range) rtrs) nil)))
     (setq rtrs (nreverse rtrs))
     (setq hlds (nreverse hlds))
     (mew-nntp-command-dispatch pro pnm directive rtrs hlds)))
@@ -188,7 +195,7 @@
       (mew-nntp-command-article pro pnm)))))
 
 (defun mew-nntp-command-article (pro pnm)
-  (mew-net-status2 (mew-nntp-get-bnm pnm) 
+  (mew-net-status2 (mew-nntp-get-status-buf pnm)
 		   (mew-nntp-get-rttl pnm)
 		   (mew-nntp-get-rcnt pnm)
 		   (nth 1 (car (mew-nntp-get-rtrs pnm)))
@@ -212,7 +219,7 @@
      ((and (eq directive 'scan) (not get-body))
       (mew-nntp-set-truncated pnm t)
       (mew-nntp-process-send-string pro "HEAD %s" uid))
-     ((or (= lim 0) (<= (string-to-int siz) lim))
+     ((or (= lim 0) (<= (string-to-number siz) lim))
       (mew-nntp-set-truncated pnm nil)
       (mew-nntp-process-send-string pro "ARTICLE %s" uid))
      (t
@@ -246,7 +253,7 @@
     (cond
      ((eq directive 'scan)
       (setq msg uid) 
-      (setq file (mew-expand-folder fld msg)))
+      (setq file (mew-expand-new-msg fld msg)))
      (t
       (setq msg-file (mew-net-get-new-message
 		      pnm fld msg 'mew-nntp-get-msgdb 'mew-nntp-set-msgdb))
@@ -265,6 +272,7 @@
 	 (mew-nntp-command-quit pro pnm)
 	 (throw 'write-error nil)))
       (mew-set-file-modes file)
+      (mew-set-file-type file)
       (mew-set-buffer-multibyte t)
       (setq vec (mew-scan-header))
       (mew-scan-set-folder vec fld)
@@ -282,7 +290,7 @@
     (mew-nntp-command-article pro pnm)))
 
 (defun mew-nntp-command-list (pro pnm)
-  (mew-net-status (mew-nntp-get-bnm pnm)
+  (mew-net-status (mew-nntp-get-status-buf pnm)
 		  "Listing"
 		  nil
 		  (mew-nntp-secure-p pnm))
@@ -385,7 +393,7 @@
 	pro tm)
     (condition-case emsg
 	(progn
-	  (setq tm (mew-timer mew-nntp-timeout-time 'mew-nntp-timeout))
+	  (setq tm (run-at-time mew-nntp-timeout-time nil 'mew-nntp-timeout))
 	  (or no-msg (message "Connecting to the NNTP server..."))
 	  (setq pro (open-network-stream pnm nil server sprt))
 	  (process-kill-without-query pro)
@@ -419,7 +427,8 @@
 	 (pnm (mew-nntp-info-name case newsgroup))
 	 (buf (get-buffer-create (mew-nntp-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
-	 process sshname sshpro sslname sslpro lport tls)
+	 process sshname sshpro sslname sslpro lport tls
+	 thread-info disp-info virtual)
     (if (mew-nntp-get-process pnm)
 	(message "Another NNTP process is running. Try later")
       (cond
@@ -437,7 +446,7 @@
 	  (setq sslname (process-name sslpro))
 	  (setq lport (mew-ssl-pnm-to-lport sslname))
 	  (when lport
-	    (setq process (mew-nntp-open pnm "localhost" lport no-msg)))))
+	    (setq process (mew-nntp-open pnm mew-ssl-localhost lport no-msg)))))
        (t
 	(setq process (mew-nntp-open pnm server port no-msg))))
       (when process
@@ -445,6 +454,7 @@
 	(mew-sinfo-set-summary-form (mew-get-summary-form bnm))
 	(mew-sinfo-set-unread-mark nil)
 	(mew-sinfo-set-scan-id nil)
+	(mew-sinfo-set-scan-md5 nil)
 	(mew-info-clean-up pnm)
 	(mew-nntp-set-no-msg pnm no-msg) ;; must come here
 	(mew-nntp-message pnm "Communicating with the NNTP server...")
@@ -458,6 +468,7 @@
 	(mew-nntp-set-status pnm "greeting")
 	(mew-nntp-set-directive pnm directive)
 	(mew-nntp-set-bnm pnm bnm)
+	(mew-nntp-set-status-buf pnm bnm)
 	(mew-nntp-set-rcnt pnm 1)
 	(mew-nntp-set-rttl pnm 0)
 	(mew-nntp-set-size pnm (mew-nntp-size case))
@@ -467,7 +478,17 @@
 	(cond
 	 ((eq directive 'get)
 	  (mew-sinfo-set-unread-mark (mew-get-unread-mark bnm))
-	  (mew-nntp-set-refs pnm (nth 0 args)))
+	  (mew-nntp-set-refs pnm (nth 0 args))
+	  (setq thread-info (nth 1 args))
+	  (mew-nntp-set-thread-info pnm thread-info)
+	  (setq disp-info (nth 1 args))
+	  (mew-nntp-set-disp-info pnm disp-info)
+	  (setq virtual (mew-net-thread-info-get-virtual thread-info))
+	  (when virtual
+	    (mew-nntp-set-status-buf pnm virtual)
+	    (save-excursion
+	      (set-buffer virtual)
+	      (mew-summary-lock process "NNTPing" (or sshpro sslpro)))))
 	 ((eq directive 'scan)
 	  (mew-nntp-set-range pnm (nth 0 args))
 	  (mew-nntp-set-get-body pnm (nth 1 args))
@@ -507,7 +528,7 @@
      (mew-set-buffer-multibyte nil)
      (insert string)
      (when (string= status "article")
-       (mew-net-status2 (mew-nntp-get-bnm pnm)
+       (mew-net-status2 (mew-nntp-get-status-buf pnm)
 			(mew-nntp-get-rttl pnm)
 			(mew-nntp-get-rcnt pnm)
 			(nth 1 (car (mew-nntp-get-rtrs pnm)))
@@ -554,8 +575,10 @@
 	 (msgid (mew-nntp-get-msgid pnm))
 	 (done (mew-nntp-get-done pnm))
 	 (error (mew-nntp-get-error pnm))
-	 (file (mew-expand-folder bnm mew-nntp-msgid-file))
-	 (buf (process-buffer process)))
+	 (file (mew-expand-file bnm mew-nntp-msgid-file))
+	 (buf (process-buffer process))
+	 (thread-info (mew-nntp-get-thread-info pnm))
+	 (disp-info (mew-nntp-get-disp-info pnm)))
     (mew-nntp-debug "NNTP SENTINEL" event)
     (set-process-buffer process nil)
     (set-buffer bnm)
@@ -570,7 +593,7 @@
 	  (when (mew-nntp-get-dispatched pnm)
 	    (cond
 	     ((eq directive 'scan)
-	      (setq msgid (int-to-string (1- (string-to-int msgid))))
+	      (setq msgid (number-to-string (1- (string-to-number msgid))))
 	      (mew-lisp-save file msgid nil 'unlimit)
 	      (setq recovered t)))
 	    (when recovered
@@ -579,6 +602,7 @@
 	       "%d message retrieved. %d messages are left due to an error"
 	       (- rttl lefts) lefts)
 	      (mew-summary-folder-cache-save))))
+      (if thread-info (mew-summary-retrieve-message-for-thread thread-info))
       (cond
        (error 
 	;; retain the error message
@@ -611,7 +635,7 @@
 	  (mew-lisp-save file msgid nil 'unlimit)
 	  (mew-summary-folder-cache-save))))))
     ;;
-    (mew-net-status-clear bnm)
+    (mew-net-status-clear (mew-nntp-get-status-buf pnm))
     (mew-info-clean-up pnm)
     (set-buffer-modified-p nil)
     (mew-summary-unlock)
@@ -619,6 +643,7 @@
 	(process-send-string sshpro "exit\n"))
     (if (and (processp sslpro) (not mew-ssl-keep-connection))
 	(delete-process sslpro))
+    (mew-net-disp-info-display disp-info)
     (run-hooks 'mew-nntp-sentinel-hook)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -644,9 +669,9 @@
 
 (defun mew-nntp-folder-load (case &optional two)
   (let* ((fld (mew-nntp-folder case))
-	 (file (mew-expand-folder fld mew-nntp-folder-alist-file))
+	 (file (mew-expand-file fld mew-nntp-folder-alist-file))
 	 (groups (mew-lisp-load file))
-	 (file2 (mew-expand-folder fld mew-nntp-folder-alist2-file))
+	 (file2 (mew-expand-file fld mew-nntp-folder-alist2-file))
 	 (groups2 (mew-lisp-load file2)))
     (mew-nntp-folder-alist-set case groups)
     (mew-nntp-folder-alist2-set case groups2)
@@ -684,7 +709,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2005 Mew developing team.
+;; Copyright (C) 1999-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
