@@ -29,7 +29,7 @@
     "size" "truncated" "get-body"
     "flush" "no-msg" "msgdb" "done" "dispatched" "error"
     "body-lines" "delete" "case"
-    "thread-info" "status-buf"))
+    "thread-info" "disp-info" "status-buf"))
 
 (mew-info-defun "mew-pop-" mew-pop-info-list)
 
@@ -241,7 +241,7 @@
      ((eq directive 'scan)
       (if (eq range nil) ;; update
 	  (setq old-uidl (mew-lisp-load
-			  (mew-expand-folder bnm mew-pop-msgid-file))))))
+			  (mew-expand-file bnm mew-pop-msgid-file))))))
     (while (re-search-forward "^\\([0-9]+\\) +\\([!-~]*\\)" nil t)
       (setq left (1+ left))
       (setq num (mew-match-string 1))
@@ -611,7 +611,7 @@
 	pro tm)
     (condition-case emsg
 	(progn
-	  (setq tm (mew-timer mew-pop-timeout-time 'mew-pop-timeout))
+	  (setq tm (run-at-time mew-pop-timeout-time nil 'mew-pop-timeout))
 	  (or no-msg (message "Connecting to the POP server..."))
 	  (setq pro (open-network-stream pnm nil server sprt))
 	  (process-kill-without-query pro)
@@ -648,7 +648,7 @@
 	 (buf (get-buffer-create (mew-pop-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
 	 process sshname sshpro sslname sslpro lport tls
-	 thread-info to-buf)
+	 thread-info disp-info virtual)
     (if (mew-pop-get-process pnm)
 	(message "Another POP process is running. Try later")
       (cond
@@ -666,7 +666,7 @@
 	  (setq sslname (process-name sslpro))
 	  (setq lport (mew-ssl-pnm-to-lport sslname))
 	  (when lport
-	    (setq process (mew-pop-open pnm "localhost" lport no-msg)))))
+	    (setq process (mew-pop-open pnm mew-ssl-localhost lport no-msg)))))
        (proxysrv
 	(setq process (mew-pop-open pnm proxysrv proxyport no-msg)))
        (t
@@ -678,6 +678,7 @@
 	(mew-sinfo-set-summary-form (mew-get-summary-form bnm))
 	(mew-sinfo-set-unread-mark nil)
 	(mew-sinfo-set-scan-id nil)
+	(mew-sinfo-set-scan-md5 nil)
 	(mew-info-clean-up pnm)
 	(mew-pop-set-no-msg pnm no-msg) ;; must come here
 	(mew-pop-message pnm "Communicating with the POP server...")
@@ -713,11 +714,13 @@
 	  (mew-pop-set-refs pnm (nth 0 args))
 	  (setq thread-info (nth 1 args))
 	  (mew-pop-set-thread-info pnm thread-info)
-	  (setq to-buf (nth 0 thread-info))
-	  (when to-buf
-	    (mew-pop-set-status-buf pnm to-buf)
+	  (setq disp-info (nth 2 args))
+	  (mew-pop-set-disp-info pnm disp-info)
+	  (setq virtual (mew-net-thread-info-get-virtual thread-info))
+	  (when virtual
+	    (mew-pop-set-status-buf pnm virtual)
 	    (save-excursion
-	      (set-buffer to-buf)
+	      (set-buffer virtual)
 	      (mew-summary-lock process "POPing" (or sshpro sslpro)))))
 	 ((eq directive 'scan)
 	  (mew-pop-set-range pnm (nth 0 args))
@@ -810,9 +813,10 @@
 	 (uidl (mew-pop-get-uidl pnm))
 	 (done (mew-pop-get-done pnm))
  	 (error (mew-pop-get-error pnm))
-	 (file (mew-expand-folder bnm mew-pop-msgid-file))
+	 (file (mew-expand-file bnm mew-pop-msgid-file))
 	 (buf (process-buffer process))
-	 (thread-info (mew-pop-get-thread-info pnm)))
+	 (thread-info (mew-pop-get-thread-info pnm))
+	 (disp-info (mew-pop-get-disp-info pnm)))
     (mew-pop-debug "POP SENTINEL" event)
     (set-process-buffer process nil)
     (set-buffer bnm)
@@ -910,6 +914,7 @@
 	(process-send-string sshpro "exit\n"))
     (if (and (processp sslpro) (not mew-ssl-keep-connection))
 	(delete-process sslpro))
+    (mew-net-disp-info-display disp-info)
     (unless (eq directive 'biff)
       (run-hooks 'mew-pop-sentinel-non-biff-hook))
     (run-hooks 'mew-pop-sentinel-hook)
@@ -931,7 +936,7 @@
       (save-excursion
 	(set-buffer case:inbox)
 	(when (and (mew-summary-exclusive-p 'no-msg)
-		   (and mew-use-cached-passwd
+		   (and (or mew-use-cached-passwd mew-use-master-passwd)
 			(setq passwd (mew-passwd-get-passwd tag))))
 	  (mew-pop-retrieve case 'biff case:inbox passwd))))))
 
@@ -951,7 +956,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2005 Mew developing team.
+;; Copyright (C) 1999-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
