@@ -254,7 +254,7 @@ guessed values."
 
 (defun mew-refile-guess-by-alist2 (regex string template)
   ;; regex: "\\([^@]+\\)@\\([^.]+\\)\\.ad\\.jp"
-  ;; string: "admin@iij.ad.jp"
+  ;; string: "admin@example.org"
   ;; template: "+net/\\2/\\1"
   ;; -> "+net/iij/admin"
   (let (str strs match repl)
@@ -268,7 +268,7 @@ guessed values."
       (setq match (cdr (cdr match))))
     (setq strs (cons nil (nreverse strs))) ;; cons nil for 0th
     (while (string-match "\\\\\\([1-9]\\)" template)
-      (setq repl (nth (string-to-int (match-string 1 template)) strs))
+      (setq repl (nth (string-to-number (match-string 1 template)) strs))
       (setq template (replace-match (or repl "") nil nil template)))
     template))
 
@@ -645,7 +645,7 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	  start)
       (set-buffer (get-buffer-create (mew-refile-log-buffer fld)))
       (goto-char (point-min))
-      (when (search-forward (concat " id=" msg-id))
+      (when (search-forward (concat " id=" msg-id) nil t)
 	(beginning-of-line)
 	(setq start (point))
 	(forward-line)
@@ -688,7 +688,7 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	  (setq folders exp-flds)
 	(unless (or auto (mew-sinfo-get-disp-msg))
 	  ;; need to make a cache or a message buffer.
-	  (mew-summary-display nil))
+	  (mew-summary-display))
 	(setq buf (mew-cache-hit fld msg))
 	(unless buf
 	  (save-excursion
@@ -703,8 +703,10 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	  (save-excursion
 	    (set-buffer fld)
 	    (setq cur-folders (cdr (mew-refile-get msg)))))
-	(setq learn-info (mew-refile-decide-folders
-			  buf msg cur-folders auto exfld))
+	(condition-case nil
+	    (setq learn-info (mew-refile-decide-folders
+			      buf msg cur-folders auto exfld))
+	  (quit (goto-char pos)))
 	(setq folders (car learn-info)))
       ;; we must prevent refiling a message to +queue
       (while folders
@@ -724,8 +726,7 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	    (save-excursion
 	      (set-buffer fld)
 	      (save-excursion
-		(when (or (re-search-forward  (mew-regex-sumsyn-msg msg) nil t)
-			  (re-search-backward (mew-regex-sumsyn-msg msg) nil t))
+		(when (mew-summary-search-msg msg)
 		  (mew-refile-reset msg)
 		  (mew-refile-set msg folders)
 		  (if cur-folders (mew-summary-refile-unlog fld))
@@ -757,10 +758,11 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	mew-inherit-refile-case
 	mew-inherit-refile-proto
 	fld msg guess)
-    (mew-summary-goto-message)
-    (when (mew-sumsyn-match mew-regex-sumsyn-short)
-      (setq fld (mew-sumsyn-folder-name))
-      (setq msg (mew-sumsyn-message-number)))
+    (save-excursion
+      (mew-summary-goto-message)
+      (when (mew-sumsyn-match mew-regex-sumsyn-short)
+	(setq fld (mew-sumsyn-folder-name))
+	(setq msg (mew-sumsyn-message-number))))
     (setq mew-inherit-refile-case  (mew-case:folder-case fld))
     (setq mew-inherit-refile-proto (mew-case:folder-folder fld))
     (with-temp-buffer
@@ -770,8 +772,8 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
       (setq guess (mew-refile-guess nil t)))
     (mew-window-configure 'message)
     ;; message buffer
+    (mew-summary-display-preamble)
     (mew-elet
-     (mew-erase-buffer)
      (save-excursion
        ;; report result of guess.
        (insert (format "** Guess result: %s\n" (car guess)))
@@ -789,8 +791,7 @@ with '\\[universal-argument]', it displays how the refile rules work in Message
 	 (insert (format "return: %s\n"
 			 (mapconcat 'identity (cdr (car guess)) ",")))
 	 (setq guess (cdr guess)))))
-    (mew-message-clear-end-of)
-    (set-buffer-modified-p nil)
+    (mew-summary-display-postscript 'no-hook)
     (select-window win)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -869,7 +870,7 @@ If '\\[universal-argument]' is specified, only messages marked with
   "\\<mew-summary-mode-map>
 Put the refile mark onto all messages marked with '*', 
 with the current folder as a candidate in addition to guessed folders.
-This is very convenient to refile all messages  picked by '\\[mew-summary-pick-mark]' and \"\\[mew-summary-grep-mark]\"."
+This is very convenient to refile all messages  picked by '\\[mew-summary-pick]'."
   (interactive)
   (mew-summary-not-in-draft
    (mew-summary-local-or-imap
@@ -890,7 +891,7 @@ This is very convenient to refile all messages  picked by '\\[mew-summary-pick-m
 (defun mew-summary-mark-refile ()
   "\\<mew-summary-mode-map>
 Put the refile mark onto all messages marked with '*'.
-This is very convenient to refile all messages picked by '\\[mew-summary-pick-mark]' and \"\\[mew-summary-grep-mark]\"."
+This is very convenient to refile all messages picked by '\\[mew-summary-pick]'."
   (interactive)
   (mew-summary-not-in-draft
    (mew-summary-local-or-imap
@@ -911,7 +912,7 @@ This is very convenient to refile all messages picked by '\\[mew-summary-pick-ma
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2005 Mew developing team.
+;; Copyright (C) 1994-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
