@@ -51,8 +51,9 @@
 effect to this function."
   (let ((mark-delete mew-mark-delete)
 	(mark-review mew-mark-review)
+	(mark-spam   mew-mark-delete)
 	(unread (and mew-use-unread-mark (mew-sinfo-get-unread-mark)))
-	duplicated review id)
+	duplicated spam review id body md5)
     (when mew-summary-form-mark-delete
       (if (mew-characterp mew-summary-form-mark-delete)
 	  (setq mark-delete mew-summary-form-mark-delete))
@@ -61,6 +62,17 @@ effect to this function."
 	    (unless (mew-scan-message-invalidp)
 	      (setq duplicated t))
 	  (mew-sinfo-set-scan-id (cons id (mew-sinfo-get-scan-id))))))
+    (when (and mew-summary-form-mark-spam
+	       (mew-sinfo-get-inboxp))
+      (if (mew-characterp mew-summary-form-mark-spam)
+	  (setq mark-spam mew-summary-form-mark-spam))
+      (setq body (MEW-BODY))
+      (unless (string= body "")
+	(setq md5 (mew-md5 body))
+	(if (member md5 (mew-sinfo-get-scan-md5))
+	    (unless (mew-scan-message-invalidp)
+	      (setq spam t))
+	  (mew-sinfo-set-scan-md5 (cons md5 (mew-sinfo-get-scan-md5))))))
     (when mew-summary-form-mark-review
       (if (mew-characterp mew-summary-form-mark-review)
 	  (setq mark-review mew-summary-form-mark-review))
@@ -75,6 +87,7 @@ effect to this function."
 	    (setq to (cdr to))))))
     (cond
      (duplicated (char-to-string mark-delete))
+     (spam       (char-to-string mark-spam))
      (review     (char-to-string mark-review))
      (unread     (char-to-string mew-mark-unread))
      (t          (char-to-string mew-mark-read)))))
@@ -99,7 +112,7 @@ effect to this function."
     (if (or (string= s "")
 	    (not (string-match mew-time-rfc-regex s)))
 	(setq s (mew-time-ctz-to-rfc
-		 (mew-file-get-time (mew-expand-folder (MEW-FLD) (MEW-NUM))))))
+		 (mew-file-get-time (mew-expand-msg (MEW-FLD) (MEW-NUM))))))
     (if (string-match mew-time-rfc-regex s)
 	(format "%02d:%02d"
 		(or (mew-time-rfc-hour) 0)
@@ -112,7 +125,7 @@ effect to this function."
     (when (or (string= s "")
 	      (not (string-match mew-time-rfc-regex s)))
       (setq s (mew-time-ctz-to-rfc
-	       (mew-file-get-time (mew-expand-folder (MEW-FLD) (MEW-NUM))))))
+	       (mew-file-get-time (mew-expand-msg (MEW-FLD) (MEW-NUM))))))
     (if (string-match mew-time-rfc-regex s)
 	(format "%02d/%02d"
 		(mew-time-mon-str-to-int (mew-time-rfc-mon))
@@ -125,7 +138,7 @@ effect to this function."
     (when (or (string= s "")
 	      (not (string-match mew-time-rfc-regex s)))
       (setq s (mew-time-ctz-to-rfc
-	       (mew-file-get-time (mew-expand-folder (MEW-FLD) (MEW-NUM))))))
+	       (mew-file-get-time (mew-expand-msg (MEW-FLD) (MEW-NUM))))))
     (if (not (string-match mew-time-rfc-regex s))
 	"0000"
       (setq year (mew-time-rfc-year))
@@ -134,7 +147,7 @@ effect to this function."
 	(setq year (+ year 2000)))
        ((< year 100)
 	(setq year (+ year 1900))))
-      (int-to-string year))))
+      (number-to-string year))))
 
 (defun mew-summary-form-size ()
   "A function to return the size of the message. Should be used
@@ -143,8 +156,8 @@ with -4. See also 'mew-summary-form-size-0k' and 'mew-summary-form-size-huge'."
 	(SIZE (mew-scan-uid-size (MEW-UID)))
 	(i 0) size unit)
     (if (and SIZE (string-match "^[0-9]+$" SIZE))
-	(setq size (string-to-int SIZE))
-      (setq size (mew-file-get-size (mew-expand-folder (MEW-FLD) (MEW-NUM)))))
+	(setq size (string-to-number SIZE))
+      (setq size (mew-file-get-size (mew-expand-msg (MEW-FLD) (MEW-NUM)))))
     (while (and (< i len-1) (>= size 1000))
       (setq size (/ size 1000))
       (setq i (1+ i)))
@@ -155,7 +168,7 @@ with -4. See also 'mew-summary-form-size-0k' and 'mew-summary-form-size-huge'."
 	  "0k"
 	(concat
 	 (if (integerp size)
-	     (int-to-string size)
+	     (number-to-string size)
 	   (format "%.0f" size))
 	 unit)))))
 
@@ -334,8 +347,10 @@ of thread indent position is returned."
 			 (car irt-list)
 			 ""))))
     (when (mew-virtual-p)
-      (setq fld (cdr (assoc (mew-scan-get-folder mew-vec)
-			    (mew-vinfo-get-lra)))))
+      (setq fld (or (cdr (assoc (mew-scan-get-folder mew-vec)
+				(mew-vinfo-get-lra)))
+		    ;; Spotlight
+		    (MEW-FLD)))) ;; xxx
     (setq msg (mew-scan-get-message mew-vec))
     (setq uid (or (mew-scan-uid-uid (MEW-UID)) ""))
     (setq siz (or (mew-scan-uid-size (MEW-UID)) ""))
@@ -355,11 +370,8 @@ of thread indent position is returned."
 	 (if (null lmsg)
 	     (goto-char (point-max))
 	   ;; a message marked with 'T'.
-	   (goto-char (point-min))
-	   (if (not (re-search-forward (mew-regex-sumsyn-msg lmsg) nil t))
-	       (goto-char (point-max)) ;; xxx
+	   (when (mew-summary-search-msg lmsg)
 	     (setq mark (mew-summary-get-mark))
-	     (beginning-of-line)
 	     (setq beg (point))
 	     (forward-line)
 	     ;; To avoid inserting a line AFTER the cursor underline,
@@ -455,8 +467,8 @@ of thread indent position is returned."
     (if (and n (< n len)) (setq ali (nth n mew-scan-fields-alias)))
     (if (stringp ali) (symbol-function (intern-soft (concat "MEW-" ali))))))
 
-(defun mew-scan-inbox-action (mew-vec)
-  (let ((alist mew-inbox-action-alist)
+(defun mew-scan-inbox-action (mew-vec case)
+  (let ((alist (mew-inbox-action-alist case))
 	ent key act val val-func ret mark-or-dst regex-list)
     (catch 'loop
       (while alist
@@ -503,7 +515,7 @@ of thread indent position is returned."
 (defun mew-scan-body (mew-vec &optional draftp)
   (forward-line)
   (let* ((i 0) (I mew-scan-max-body-length)
-	 (j 0) (J 3)
+	 (j 0) (J mew-scan-body-length)
 	 (ctr (MEW-CT))
 	 (cte (MEW-CTE))
 	 (body "")
@@ -592,13 +604,17 @@ of thread indent position is returned."
 (defsubst mew-scan-uid-size (uid)
   (nth 1 (mew-split uid mew-sp)))
 
-(defun mew-header-insert-xmu (uid siz truncated)
+(defsubst mew-scan-uid-case (uid)
+  (nth 2 (mew-split uid mew-sp)))
+
+(defun mew-header-insert-xmu (uid siz truncated &optional case)
   (when (and (stringp uid) (stringp siz))
-    (setq siz (int-to-string (string-to-int siz))) ;; removing 0
+    (setq siz (number-to-string (string-to-number siz))) ;; removing 0
     (let (fields)
-      (if truncated
-	  (setq fields (concat uid " 0" siz)) ;; e.g. 0500 == truncated
-	(setq fields (concat uid " " siz)))
+      (if (not truncated)
+	  (setq fields (concat uid " " siz))
+	(setq fields (concat uid " 0" siz)) ;; e.g. 0500 == truncated
+	(if case (setq fields (concat fields " " case))))
       (save-excursion
 	(mew-header-delete-lines (list mew-x-mew-uidl:)))
       (mew-header-insert mew-x-mew-uidl: fields 'no-fold))))
@@ -614,7 +630,7 @@ of thread indent position is returned."
 ;;; Scanning a folder
 ;;;
 
-(defun mew-summary-ls (&optional header-only goend)
+(defun mew-summary-ls (&optional header-only goend update)
   "List this folder asynchronously.
 
 In a LOCAL folder: messages in the local folder are scanned according
@@ -637,12 +653,18 @@ non-nil, only headers of messages are cached. If executed with
 	    scanp range dir-newp)
        (mew-summary-folder-cache-load)
        (cond
+	(update
+	 (setq askp nil)
+	 (setq range nil) ;; update
+	 (setq scanp t))
 	((interactive-p) ;; "s"
 	 (setq askp t)
 	 (setq scanp t))
 	((mew-summary-folder-dir-newp) ;; "g"
 	 (setq askp nil)
 	 (setq scanp t)))
+       ;; for mew-summary-exchange-point.
+       (mew-sinfo-set-ret-pos (point))
        (if (mew-summary-folder-dir-newp) (setq dir-newp t))
        (if (or (interactive-p) goend) (goto-char (point-max)))
        (set-buffer-modified-p nil)
@@ -658,7 +680,7 @@ non-nil, only headers of messages are cached. If executed with
 		(not (mew-folder-imap-queuep)))
 	   (if (and dir-newp (mew-folder-imapp fld))
 	       (mew-local-retrieve 'scan bnm (mew-range-update bnm))
-	     (setq range (mew-input-range-remote bnm))
+	     (if askp (setq range (mew-input-range-remote bnm)))
 	     (when (eq range 'sync)
 	       (setq range nil)
 	       (setq directive 'sync))
@@ -712,7 +734,7 @@ non-nil, only headers of messages are cached. If executed with
 
 (defsubst mew-summary-folder-cache-newp ()
   (let* ((folder (mew-summary-folder-name 'ext))
-	 (cache (mew-expand-folder folder mew-summary-cache-file))
+	 (cache (mew-expand-file folder mew-summary-cache-file))
 	 (t1 (mew-file-get-time cache))
 	 (t2 (mew-sinfo-get-cache-time)))
     (mew-compare-times t1 t2)))
@@ -739,7 +761,7 @@ non-nil, only headers of messages are cached. If executed with
 
 (defun mew-summary-folder-cache-load ()
   (let* ((folder (mew-summary-folder-name 'ext))
-	 (cache (mew-expand-folder folder mew-summary-cache-file))
+	 (cache (mew-expand-file folder mew-summary-cache-file))
 	 refile refs)
     (when (and (file-readable-p cache)
 	       (mew-summary-folder-cache-newp))
@@ -762,7 +784,7 @@ non-nil, only headers of messages are cached. If executed with
 
 (defun mew-summary-folder-cache-save ()
   (let* ((folder (mew-summary-folder-name 'ext))
-	 (cache (mew-expand-folder folder mew-summary-cache-file)))
+	 (cache (mew-expand-file folder mew-summary-cache-file)))
     (when (file-writable-p cache)
       (mew-touch-folder folder)
       (save-restriction
@@ -800,7 +822,7 @@ non-nil, only headers of messages are cached. If executed with
 	(set-buffer folder)
 	(mew-erase-buffer)
 	(set-buffer-modified-p nil)))
-  (let ((cfile (mew-expand-folder folder mew-summary-cache-file)))
+  (let ((cfile (mew-expand-file folder mew-summary-cache-file)))
     (if (file-exists-p cfile)
 	(write-region "" nil cfile nil 'no-msg))))
 
@@ -808,7 +830,7 @@ non-nil, only headers of messages are cached. If executed with
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2005 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
