@@ -27,16 +27,19 @@
 
 (defun mew-smime-verify-check ()
   (goto-char (point-min))
-  (if (search-forward "Good signature" nil t)
+  (if (search-forward "Good sign" nil t)
       (if (re-search-forward "aka \"\\(.*\\)\"" nil t)
-	  (format "S/MIME Good signature <%s>" (mew-match-string 1))
-	"S/MIME Good signature")
+	  (format "Good S/MIME sign <%s>" (mew-match-string 1))
+	"Good S/MIME sign")
     (goto-char (point-min))
-    (if (search-forward "invalid signature" nil t)
-	"S/MIME Bad signature"
+    (if (search-forward "invalid sign" nil t)
+	"BAD S/MIME sign"
       (if (re-search-forward "invalid certification chain: \\(.*\\)" nil t)
-	  (format "S/MIME signature %s" (mew-match-string 1))
-	"S/MIME NEED TO HACK"))))
+	  (format "S/MIME sign %s" (mew-match-string 1))
+	(goto-char (point-min))
+	(if (re-search-forward "no signature value available" nil t)
+	    "S/MIME no signature"
+	  "S/MIME NEED TO HACK")))))
 
 (defun mew-smime-verify (file1 file2)
   (message "S/MIME verifying...")
@@ -107,7 +110,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2004 Mew developing team.
+;; Copyright (C) 2004-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
