@@ -15,21 +15,21 @@
 (defvar mew-smtp-info-list
   '(;; parameters to be saved
     "raw-header" "recipients" "orig-recipients"
-    "bcc" "dcc" "fcc" "msgid" "logtime"
+    "bcc" "fcc" "msgid" "logtime"
     "case" ;; save for re-edit
     ;; parameters used internally
     "server" "port" "ssh-server"
-    "user" "auth-list" "account"
+    "user" "auth-user" "auth-list"
     "helo-domain" 
     "status" "process" "ssh-process" "ssl-process"
     "qfld" "messages"
     ;; parameters used internally and should be initialized
     "string" "error" "auth-selected" "timer" "cont" "from" "sender"
-    "done" "imapp"))
+    "done" "imapp" "capa" "fallback"))
 
 (mew-info-defun "mew-smtp-" mew-smtp-info-list)
 
-(defvar mew-smtp-info-list-save-length 9)
+(defvar mew-smtp-info-list-save-length 8)
 (defvar mew-smtp-info-list-clean-length 21)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -39,14 +39,18 @@
 
 (defvar mew-smtp-fsm
   '(("greeting"      ("220" . "ehlo"))
-    ("ehlo"          ("250" . "auth") (t . "helo"))
+    ("ehlo"          ("250" . "post-ehlo") (t . "helo"))
     ;;
     ("auth"          ("250" . "next"))
     ("auth-cram-md5" ("334" . "pwd-cram-md5") (t . "wpwd"))
     ("pwd-cram-md5"  ("235" . "next") (t . "wpwd"))
-    ("auth-login"    ("334" . "pwd-login") (t . "wpwd"))
+    ("auth-login"    ("334" . "user-login") (t . "wpwd"))
+    ("user-login"    ("334" . "pwd-login") (t . "wpwd"))
     ("pwd-login"     ("235" . "next") (t . "wpwd"))
     ("auth-plain"    ("235" . "next") (t . "wpwd"))
+;; See blow
+;;    ("auth-plain"    ("334" . "pwd-plain") (t . "wpwd"))
+;;    ("pwd-plain"     ("235" . "next") (t . "wpwd"))
     ;;
     ("helo"          ("250" . "next"))
     ("mail-from"     ("250" . "rcpt-to"))
@@ -66,38 +70,53 @@
 ;;; Filters
 ;;;
 
-(defun mew-smtp-command-ehlo (pro pnm)
-  (let ((helo-domain (mew-smtp-get-helo-domain pnm)))
-    (mew-smtp-process-send-string pro "EHLO %s" helo-domain)))
-
 (defun mew-smtp-command-helo (pro pnm)
   (let ((helo-domain (mew-smtp-get-helo-domain pnm)))
     (mew-smtp-process-send-string pro "HELO %s" helo-domain)))
 
+(defun mew-smtp-command-ehlo (pro pnm)
+  (let ((helo-domain (mew-smtp-get-helo-domain pnm)))
+    (mew-smtp-process-send-string pro "EHLO %s" helo-domain)))
+
+(defun mew-smtp-command-post-ehlo (pro pnm)
+  (let ((str (mew-smtp-get-string pnm)) (start 0) capa)
+    (catch 'loop
+      (while (string-match "^250\\([- ]?\\)\\(.*\\)$" str start)
+	(setq capa (cons (mew-split (match-string 2 str) 32) capa))
+	(if (string= (match-string 1 str) " ")
+	    (throw 'loop nil))
+	(setq start (match-end 0))))
+    (mew-smtp-set-capa pnm (nreverse capa))
+    (mew-smtp-set-status pnm "auth")
+    (mew-smtp-command-auth pro pnm)))
+
 (defun mew-smtp-command-auth (pro pnm)
-  (cond
-   ((mew-smtp-get-user pnm)
-    (let ((auth-list (mew-smtp-get-auth-list pnm))
-	  (str (mew-smtp-get-string pnm)) auth func)
-      (if (and (string-match "AUTH \\([^\r\n]+\\)\r?\n" str)
-	       (setq auth (mew-auth-select (match-string 1 str) auth-list))
+  (let* ((case (mew-smtp-get-case pnm))
+	 (use-smtp-auth (mew-use-smtp-auth case))
+	 (capa (mew-smtp-get-capa pnm))
+	 (auths (assoc "AUTH" capa))
+	 (auth-list (mew-smtp-get-auth-list pnm))
+	 auth func)
+    (cond
+     ((and use-smtp-auth auths)
+      (if (and (setq auth (mew-auth-select2 auths auth-list))
 	       (setq func (mew-smtp-auth-get-func auth))
 	       (fboundp func))
 	  (progn
 	    (mew-smtp-set-auth-selected pnm auth)
 	    (funcall func pro pnm))
 	(mew-smtp-debug "<AUTH>" "No preferred SMTP AUTH.\n")
-	;; xxx how should we act?
-	(mew-smtp-set-status pnm "next")
-	(mew-smtp-command-next pro pnm))))
-   (t
-    (mew-smtp-set-status pnm "next")
-    (mew-smtp-command-next pro pnm))))
+	(mew-smtp-command-wpwd pro pnm)))
+     (t
+      (mew-smtp-set-status pnm "next")
+      (mew-smtp-command-next pro pnm)))))
 
 (defun mew-smtp-command-wpwd (pro pnm)
   (let ((auth (mew-smtp-get-auth-selected pnm)))
     (mew-passwd-set-passwd (mew-smtp-passtag pnm) nil)
-    (mew-smtp-set-error pnm (format "SMTP %s password is wrong!" auth))
+    (if auth
+	(mew-smtp-set-error pnm (format "SMTP %s password is wrong!" auth))
+      (mew-smtp-set-error pnm "No SMTP AUTH available!"))
     (mew-smtp-command-quit2 pro pnm)))
 
 (defun mew-smtp-command-next (pro pnm)
@@ -195,7 +214,6 @@
   (let ((fcc (mew-smtp-get-fcc pnm))
 	(case (mew-smtp-get-case pnm))
 	(back (mew-queue-backup (buffer-file-name) mew-queue-info-suffix))
-	(buf (process-buffer pro))
 	imapp)
     ;; mew-folder-new-message may be slow if the folder contains
     ;; a lot of messages. So, let's Fcc in background.
@@ -204,8 +222,6 @@
     (mew-smtp-log pnm)
     (if (mew-smtp-get-bcc pnm)
 	(mew-smtp-bcc pro pnm back)
-      (set-process-buffer pro nil)
-      (mew-remove-buffer buf)
       (mew-smtp-set-status pro "next")
       (mew-smtp-command-next pro pnm))))
 
@@ -225,13 +241,13 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
-;;; AUTH
+;;; SMTP AUTH (RFC 2554)
 ;;;
 
 (defvar mew-smtp-auth-alist
-  '(("CRAM-MD5" mew-smtp-command-auth-cram-md5)
-    ("PLAIN"    mew-smtp-command-auth-plain)
-    ("LOGIN"    mew-smtp-command-auth-login)))
+  '(("CRAM-MD5" mew-smtp-command-auth-cram-md5)  ;; RFC 2195
+    ("PLAIN"    mew-smtp-command-auth-plain)     ;; RFC 2595
+    ("LOGIN"    mew-smtp-command-auth-login)))   ;; No spec
 
 (defsubst mew-smtp-auth-get-func (auth)
   (nth 1 (mew-assoc-case-equal auth mew-smtp-auth-alist 0)))
@@ -243,39 +259,74 @@
   (mew-smtp-set-status pnm "auth-cram-md5"))
 
 (defun mew-smtp-command-pwd-cram-md5 (pro pnm)
-  (let ((str (mew-smtp-get-string pnm))
-	(user (mew-smtp-get-user pnm))
-        (prompt (format "SMTP CRAM-MD5 password (%s): "
-                        (mew-smtp-get-account pnm)))
-	challenge passwd cram-md5)
+  (let* ((str (mew-smtp-get-string pnm))
+	 (user (mew-smtp-get-auth-user pnm))
+	 (prompt (format "SMTP CRAM-MD5 password (%s): " user))
+	 challenge passwd cram-md5)
     (if (string-match " \\([a-zA-Z0-9+/]+=*\\)" str) ;; xxx
 	(setq challenge (match-string 1 str)))
     (setq passwd (mew-smtp-input-passwd prompt pnm))
     (setq cram-md5 (mew-cram-md5 user passwd challenge))
     (mew-smtp-process-send-string pro cram-md5)))
 
+;; There are two variations for SMTP AUTH LOGIN.
+;; 2) AUTH PLAIN then id then password
+;; 1) AUTH PLAIN id then password
+;;
+;; 1) is popular however.
+;; And a server of an ISP supports 1) only.
+
 (defun mew-smtp-command-auth-login (pro pnm)
-  (let* ((user (mew-smtp-get-user pnm))
-	 (euser (mew-base64-encode-string user)))
-    (mew-smtp-process-send-string pro "AUTH LOGIN %s" euser)
-    (mew-smtp-set-status pnm "auth-login")))
+  (mew-smtp-process-send-string pro "AUTH LOGIN")
+  (mew-smtp-set-status pnm "auth-login"))
+
+(defun mew-smtp-command-user-login (pro pnm)
+  (let* ((user (mew-smtp-get-auth-user pnm))
+         (euser (mew-base64-encode-string user)))
+     (mew-smtp-process-send-string pro "%s" euser)))
 
 (defun mew-smtp-command-pwd-login (pro pnm)
-  (let* ((prompt (format "SMTP LOGIN password (%s): "
-                         (mew-smtp-get-account pnm)))
+  (let* ((user (mew-smtp-get-auth-user pnm))
+	 (prompt (format "SMTP LOGIN password (%s): " user))
          (passwd (mew-smtp-input-passwd prompt pnm))
 	 (epasswd (mew-base64-encode-string passwd)))
     (mew-smtp-process-send-string pro epasswd)))
 
+;; There are two variations for SMTP AUTH PLAIN.
+;; 1) AUTH PLAIN then id+password
+;; 2) AUTH PLAIN id+password
+;;
+;; 1) is popular however a server of an ISP supports 2) only, sigh.
+
 (defun mew-smtp-command-auth-plain (pro pnm)
-  (let* ((prompt (format "SMTP PLAIN password (%s): "
-                         (mew-smtp-get-account pnm)))
-         (passwd (mew-smtp-input-passwd prompt pnm))
-	 (user (mew-smtp-get-user pnm))
-	 (plain (mew-base64-encode-string (format "\0%s\0%s" user passwd))))
+  (let* ((case (mew-smtp-get-case pnm))
+	 (user (mew-smtp-get-auth-user pnm))
+	 (authorize-id (mew-smtp-auth-plain-authorize-id case))
+	 (prompt (format "SMTP PLAIN password (%s): " user))
+	 (passwd (mew-smtp-input-passwd prompt pnm))
+	 (plain (mew-base64-encode-string
+		 (if authorize-id
+		     (format "%s\0%s\0%s" user user passwd)
+		   (format "\0%s\0%s" user passwd)))))
     (mew-smtp-process-send-string pro "AUTH PLAIN %s" plain)
     (mew-smtp-set-status pnm "auth-plain")))
 
+;; (defun mew-smtp-command-auth-plain (pro pnm)
+;;   (mew-smtp-process-send-string pro "AUTH PLAIN")
+;;   (mew-smtp-set-status pnm "auth-plain"))
+
+;; (defun mew-smtp-command-pwd-plain (pro pnm)
+;;   (let* ((case (mew-smtp-get-case pnm))
+;; 	 (user (mew-smtp-get-auth-user pnm))
+;; 	 (authorize-id (mew-smtp-auth-plain-authorize-id case))
+;; 	 (prompt (format "SMTP PLAIN password (%s): " user))
+;;          (passwd (mew-smtp-input-passwd prompt pnm))
+;; 	 (plain (mew-base64-encode-string
+;; 		 (if authorize-id
+;; 		     (format "%s\0%s\0%s" user user passwd)
+;; 		   (format "\0%s\0%s" user passwd)))))
+;;     (mew-smtp-process-send-string pro "%s" plain)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Sub functions
@@ -283,15 +334,20 @@
 
 (defconst mew-smtp-info-prefix "mew-smtp-info-")
 
-(defsubst mew-smtp-info-name (case)
+(defsubst mew-smtp-info-name (case &optional fallbacked)
   (let ((server (mew-smtp-server case))
 	(port (mew-smtp-port case))
-	(user (mew-smtp-user case))
+	(user (mew-smtp-user-only case))
 	(sshsrv (mew-smtp-ssh-server case))
 	(name mew-smtp-info-prefix))
     (if user
 	(setq name (concat name user "@" server))
       (setq name (concat name server)))
+    (when (and (not fallbacked)
+	       mew-use-submission ;; xxx to be deleted
+	       (fboundp 'make-network-process)
+	       (string= port "smtp"))
+      (setq port "submission"))
     (unless (string= port mew-smtp-port)
       (setq name (concat name ":" port)))
     (if sshsrv
@@ -324,14 +380,40 @@
 ;;; Opening SMTP
 ;;;
 
+(defvar mew-use-submission nil)
+
+(defvar mew-smtp-submission-timeout 10)
+(defun mew-smtp-submission-timeout (pro)
+  (when (and (processp pro) (eq (process-status pro) 'connect))
+    (mew-smtp-sentinel pro "time out - failed\n")))
+
+(defvar mew-smtp-submission-family 'ipv4)
+
+(if (fboundp 'make-network-process)
+    (defun mew-open-network-stream (name buf server port)
+      (let (family nowait pro)
+	(when mew-inherit-submission
+	  (setq family mew-smtp-submission-family)
+	  (setq nowait t))
+	(setq pro (make-network-process :name name :buffer buf
+					:host server :service port
+					:family family :nowait nowait))
+ 	(if nowait
+	    (run-at-time mew-smtp-submission-timeout nil 'mew-smtp-submission-timeout pro))
+	pro))
+  (defalias 'mew-open-network-stream 'open-network-stream))
+
 (defun mew-smtp-open (pnm server port)
   (let ((sprt (mew-port-sanity-check port))
 	pro tm)
+    ;; xxx some OSes do not define "submission", sigh.
+    (when (and (stringp sprt) (string= sprt "submission"))
+      (setq sprt (string-to-int (mew-serv-to-port sprt))))
     (condition-case emsg
 	(progn
-	  (setq tm (mew-timer mew-smtp-timeout-time 'mew-smtp-timeout))
+	  (setq tm (run-at-time mew-smtp-timeout-time nil 'mew-smtp-timeout))
 	  (message "Connecting to the SMTP server...")
-	  (setq pro (open-network-stream pnm nil server sprt))
+	  (setq pro (mew-open-network-stream pnm nil server sprt))
 	  (process-kill-without-query pro)
 	  (mew-set-process-cs pro mew-cs-text-for-net mew-cs-text-for-net)
 	  (message "Connecting to the SMTP server...done"))
@@ -352,15 +434,34 @@
 ;;; Launcher
 ;;;
 
-(defun mew-smtp-send-message (case qfld msgs)
+(defun mew-smtp-send-message (case qfld msgs &optional fallbacked)
   (let ((server (mew-smtp-server case))
-        (user (mew-smtp-user case))
+        (user (mew-smtp-user-only case))
 	(port (mew-smtp-port case))
-	(pnm (mew-smtp-info-name case))
+	(pnm (mew-smtp-info-name case fallbacked))
 	(sshsrv (mew-smtp-ssh-server case))
 	(sslp (mew-smtp-ssl case))
 	(sslport (mew-smtp-ssl-port case))
-	process sshname sshpro sslname sslpro lport)
+	mew-inherit-submission
+	process sshname sshpro sslname sslpro lport tlsp tls fallback)
+    (when (and sslp (string= port sslport))
+      (setq tlsp t)
+      ;; let stunnel know that a wrapper protocol is SMTP
+      (setq tls mew-tls-smtp))
+    ;; a fallback: "submission" -> "smtp"
+    ;; mew-smtp-port is "smtp" and mew-use-submission is t on Emacs 22
+    (when (and (or (not sslp) tlsp)
+	       (not fallbacked)
+	       mew-use-submission
+	       (fboundp 'make-network-process) ;; Emacs 22 or later
+	       (string= port "smtp"))
+      (setq port "submission")
+      (setq fallback t)
+      (unless tlsp
+	;; TLS uses stunnel. So, we should not use non-blocking connect.
+	;; Timeout should be carried out by stunnel.
+	(setq mew-inherit-submission t))
+      (if (string= sslport "smtp") (setq sslport "submission")))
     (cond
      (sshsrv
       (setq sshpro (mew-open-ssh-stream case server port sshsrv))
@@ -370,12 +471,12 @@
 	(when lport
 	  (setq process (mew-smtp-open pnm "localhost" lport)))))
      (sslp
-      (setq sslpro (mew-open-ssl-stream server sslport))
+      (setq sslpro (mew-open-ssl-stream case server sslport tls))
       (when sslpro
 	(setq sslname (process-name sslpro))
 	(setq lport (mew-ssl-pnm-to-lport sslname))
 	(when lport
-	  (setq process (mew-smtp-open pnm "localhost" lport)))))
+	  (setq process (mew-smtp-open pnm mew-ssl-localhost lport)))))
      (t
       (setq process (mew-smtp-open pnm server port))))
     (if (null process)
@@ -383,9 +484,19 @@
 	 ((and sshsrv (null sshpro))
 	  (message "Cannot create to the SSH connection"))
 	 ((and sslp (null sslpro))
-	  (message "Cannot create to the SSL connection"))
+	  (message "Cannot create to the SSL/TLS connection"))
 	 (t
-	  (message "Cannot connect to the SMTP server")))
+	  (if (and (or (not sslp) tlsp)
+		   (not fallbacked)
+		   mew-use-submission
+		   (fboundp 'make-network-process)
+		   (string= port "submission"))
+	      (progn
+		;; make-network-process with :nowait t sometime
+		;; returns nil, why?
+		(mew-smtp-send-message case qfld msgs t)
+		(mew-info-clean-up pnm))
+	    (message "Cannot connect to the SMTP server"))))
       (mew-info-clean-up pnm mew-smtp-info-list-clean-length)
       (mew-smtp-set-case pnm case)
       (mew-smtp-set-qfld pnm qfld)
@@ -398,9 +509,10 @@
       (mew-smtp-set-ssl-process pnm sslpro)
       (mew-smtp-set-helo-domain pnm (mew-smtp-helo-domain case))
       (mew-smtp-set-user pnm user)
-      (mew-smtp-set-account pnm (format "%s@%s" user server))
+      (mew-smtp-set-auth-user pnm (mew-smtp-user case))
       (mew-smtp-set-auth-list pnm (mew-smtp-auth-list case))
       (mew-smtp-set-status pnm "greeting")
+      (mew-smtp-set-fallback pnm fallback)
       ;;
       (set-process-buffer process nil)
       (set-process-sentinel process 'mew-smtp-sentinel)
@@ -410,13 +522,15 @@
 (defun mew-smtp-flush-queue (case &optional qfld)
   (let (msgs)
     (unless qfld (setq qfld (mew-queue-folder case)))
-    (setq msgs (mew-folder-messages qfld))
-    (when msgs
-      (mew-summary-folder-cache-clean qfld)
-      (run-hooks 'mew-smtp-flush-hook)
-      (message "Flushing %s..." qfld)
-      (mew-smtp-send-message case qfld msgs))))
-
+    (if (mew-smtp-get-server (mew-smtp-info-name case)) ;; lock
+	(message "%s is locked" qfld)
+      (setq msgs (mew-folder-messages qfld))
+      (when msgs
+	(mew-summary-folder-cache-clean qfld)
+	(run-hooks 'mew-smtp-flush-hook)
+	(message "Flushing %s..." qfld)
+	(mew-smtp-send-message case qfld msgs)))))
+  
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Filter and sentinel
@@ -431,7 +545,6 @@
 
 (defun mew-smtp-filter (process string)
   (let* ((pnm (process-name process))
-	 (case (mew-smtp-get-case pnm))
 	 (status (mew-smtp-get-status pnm))
 	 (str (concat (mew-smtp-get-string pnm) string))
 	 (buf (process-buffer process))
@@ -455,19 +568,42 @@
 	(if (string-match "^pwd-" status)
 	    (mew-smtp-set-error pnm "SMTP password is wrong!")
 	  (if (string-match "\n$" str)
-	      (setq str (substring str 0 (1- (length str)))))
+	      (setq str (substring str 0 -1)))
 	  (unless (string-match "[.!]$" str)
 	    (setq str (concat str "."))))
-	(if (null buf)
-	    ;; A message file is not inserted at the beginning of the SMTP
-	    ;; session.
-	    ()
-	  (mew-smtp-queue case str))
 	(mew-smtp-set-error pnm str)
 	(mew-smtp-command-quit2 process pnm))))
      (t ())))) ;; stay
 
 (defun mew-smtp-sentinel (process event)
+  (mew-smtp-debug "SMTP SENTINEL" event)
+  (let* ((pnm (process-name process))
+	 (pro (mew-smtp-get-process pnm))
+	 (case (mew-smtp-get-case pnm))
+	 (qfld (mew-smtp-get-qfld pnm))
+	 (msgs (mew-smtp-get-messages pnm))
+	 (fallback (mew-smtp-get-fallback pnm))
+	 (status (mew-smtp-get-status pnm)))
+    (cond
+     ((or (string-match "failed" event)
+	  (and (string= status "greeting")
+	       (string-match "connection broken by remote peer" event)))
+      (if fallback
+	  (progn
+	    (mew-smtp-send-message case qfld msgs fallback)
+	    ;; A failed process stays
+	    (when (memq (process-status pro) '(failed connect))
+	      (delete-process pro)
+	      (mew-info-clean-up pnm)))
+	(mew-smtp-set-error pnm (substring event 0 -1))
+	(mew-smtp-sentinel2 process event)))
+     ((string-match "open" event)
+      ;; OK connected
+      )
+     (t
+      (mew-smtp-sentinel2 process event)))))
+
+(defun mew-smtp-sentinel2 (process event)
   (let* ((pnm (process-name process))
 	 (buf (process-buffer process))
 	 (qfld (mew-smtp-get-qfld pnm))
@@ -477,10 +613,14 @@
 	 (error (mew-smtp-get-error pnm))
 	 (sshpro (mew-smtp-get-ssh-process pnm))
 	 (sslpro (mew-smtp-get-ssl-process pnm)))
-    (mew-smtp-debug "SMTP SENTINEL" event)
     (cond
      (error
       (message "%s  This mail has been queued to %s" error qfld)
+      (when buf
+	;; A message file is not inserted at the beginning of the SMTP
+	;; session.
+	(set-buffer buf)
+	(mew-smtp-queue case error))
       (mew-smtp-log pnm error))
      (done
       (message "Sending in background...done"))
@@ -495,7 +635,8 @@
     (if (and (processp sslpro) (not mew-ssl-keep-connection))
 	(delete-process sslpro))
     (run-hooks 'mew-smtp-sentinel-hook)
-    (if imapp (mew-imap2-fcc case))))
+    (if (and done imapp) (mew-imap2-fcc case))
+    (when buf (mew-remove-buffer buf))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -526,10 +667,9 @@
 	(setq i (1+ i)))
       (mew-lisp-save info data))
     ;;
-    (mew-remove-buffer (current-buffer))
     (message "%s has been queued to %s (%s)" oname nname err)
     (mew-touch-folder qfld)
-    file))
+    (file-name-sans-extension file)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -593,7 +733,7 @@
       (and msgid (insert " id=" msgid))
       (and server (insert " server=" server))
       (and sshsrv (insert " sshsrv=" sshsrv))
-      (and sslp (insert " SSL"))
+      (and sslp (insert " SSL/TLS"))
       (and recipients
 	   (setq recipients (mapconcat 'identity recipients ",")))
       (and recipients (insert " recipients=" recipients))
@@ -611,7 +751,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2003 Mew developing team.
+;; Copyright (C) 1999-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
