@@ -28,7 +28,7 @@
   (let ((ret (mew-subject-simplify key nil 'no-replace)))
     (if (string-match "^[[(][^])]+[])][ \t]*" ret)
 	(progn
-	  (setq ret (substring ret (match-end 0) nil))
+	  (setq ret (substring ret (match-end 0)))
 	  (mew-subject-simplify ret nil 'no-replace))
       ret)))
 
@@ -44,21 +44,21 @@
      (t
       (setq mlname "")
       (setq mlnum "0")))
-    (concat mlname (format "\000%010d" (string-to-int mlnum)))))
+    (concat mlname (format "\000%010d" (string-to-number mlnum)))))
 
 (defsubst mew-sort-key-date (key folder msg)
   (if (string= key "")
-      (let ((time (mew-file-get-time (mew-expand-folder folder msg))))
+      (let ((time (mew-file-get-time (mew-expand-msg folder msg))))
 	(mew-time-ctz-to-sortkey time))
     (mew-time-rfc-to-sortkey key)))
 
 (defsubst mew-sort-key-num (key folder msg)
-  (string-to-int key))
+  (string-to-number key))
 
 (defsubst mew-sort-key-postnum (key folder msg)
   (if (string-match "[0-9]+$" key)
-      (string-to-int (match-string 0 key))
-    (string-to-int key)))
+      (string-to-number (match-string 0 key))
+    (string-to-number key)))
 
 (defsubst mew-sort-key (x) (cdr x))
 
@@ -91,7 +91,7 @@
        (insert (format "move %s to %s\n" src dst)))
     (mew-elet
      (let (beg end line)
-       (rename-file src dst)
+       (rename-file (mew-msg-get-filename src) (mew-msg-new-filename dst))
        (mew-refile-change src dst)
        (cond
 	(lastp
@@ -100,9 +100,7 @@
 	   (mew-sort-insert mew-sort-line dst)
 	   nil))
 	((null pos) ;; first
-	 (goto-char (point-min))
-	 (when (re-search-forward (mew-regex-sumsyn-msg src) nil t)
-	   (beginning-of-line)
+	 (when (mew-summary-search-msg src)
 	   (setq beg (point))
 	   (forward-line)
 	   (setq end (point))
@@ -112,9 +110,7 @@
 	   (delete-region beg end)
 	   beg))
 	(t
-	 (goto-char (point-min))
-	 (when (re-search-forward (mew-regex-sumsyn-msg src) nil t)
-	   (beginning-of-line)
+	 (when (mew-summary-search-msg src)
 	   (setq beg (point))
 	   (forward-line)
 	   (setq end (point))
@@ -223,6 +219,7 @@ sorted. But if you do so, '\\<mew-summary-mode-map>\\[mew-summary-ls]' + 'sync'
 	    (with-temp-buffer
 	      (call-process mew-prog-mewl nil t nil
 			    "-b" mew-mail-path "-l" "0"
+			    "-x" mew-suffix
 			    "-d" key "-s" (concat fld " " range))
 	      (goto-char (point-min))
 	      (while (not (eobp))
@@ -247,7 +244,6 @@ sorted. But if you do so, '\\<mew-summary-mode-map>\\[mew-summary-ls]' + 'sync'
 	    (mew-elet
 	     (mew-erase-buffer)
 	     (insert "Sort as follows:\n")))
-	  ;; for C-xC-x
 	  (when (and (not (mew-debug 'sort)) (not (eobp)))
 	    (beginning-of-line)
 	    (mew-elet
@@ -310,7 +306,7 @@ sorted. But if you do so, '\\<mew-summary-mode-map>\\[mew-summary-ls]' + 'sync'
 	   (t
 	    (let ((orig (next-single-property-change
 			 (point-min) 'mew-sort-orig)))
-	      ;; 'mew-sort-orign may start with bob.
+	      ;; 'mew-sort-orig may start with bob.
 	      (if (null orig)
 		  (mew-push-mark)
 		(save-excursion
@@ -345,7 +341,7 @@ sorted. But if you do so, '\\<mew-summary-mode-map>\\[mew-summary-ls]' + 'sync'
 
 (defun mew-summary-pack-rename (src dst)
   (mew-elet
-   (rename-file src dst)
+   (rename-file (mew-msg-get-filename src) (mew-msg-new-filename dst))
    (mew-refile-change src dst)
    (when (re-search-forward (mew-regex-sumsyn-msg src) nil t)
      (mew-syntax-change-message-number2 dst)
@@ -383,7 +379,7 @@ local cache messages are packed."
     (condition-case nil
 	(progn
 	  (setq msgs (mew-dir-messages "."))
-	  (setq msgs (mapcar 'string-to-int msgs))
+	  (setq msgs (mapcar 'string-to-number msgs))
 	  (setq msgs (sort msgs '<)) ;; sort is inevitable
 	  ;; the cursor stays the current position.
 	  (save-excursion
@@ -391,17 +387,17 @@ local cache messages are packed."
 	    (while msgs
 	      (setq msg (car msgs))
 	      (setq msgs (cdr msgs))
-	      (setq src (int-to-string msg))
+	      (setq src (number-to-string msg))
 	      (cond
 	       ((= msg n);; including src is a directory
 		(setq n (1+ n)))
 	       ((file-directory-p src)
 		)
 	       (t
-		(setq dst (int-to-string n))
+		(setq dst (number-to-string n))
 		(while (file-exists-p dst)
 		  (setq n (1+ n))
-		  (setq dst (int-to-string n)))
+		  (setq dst (number-to-string n)))
 		(mew-summary-pack-rename src dst)
 		(setq n (1+ n))))))
 	  (mew-summary-folder-cache-save)
@@ -417,7 +413,7 @@ local cache messages are packed."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2003 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
