@@ -87,7 +87,7 @@ after ':'."
 	 (i 0) (N mew-ssh-process-exec-cnt)
 	 (pros (process-list))
 	 (regex (mew-ssh-info-name-regex sshserver server remoteport))
-	 buf name pnm pro status)
+	 name pnm pro status)
     (cond
      ((not (and (stringp server) (stringp serv) (stringp sshserver)))
       ())
@@ -106,12 +106,11 @@ after ':'."
 	  pro
 	(message "Connecting to the SSH server...")
 	(setq pro nil)
-	(setq buf (generate-new-buffer (concat mew-buffer-prefix "ssh")))
 	(catch 'loop
 	  (while (< i N)
 	    (setq name (mew-ssh-info-name sshserver server remoteport localport))
 	    (setq pro (apply 'start-process
-			     name buf
+			     name nil
 			     ssh "-x" "-v" "-L"
 			     (format "%d:%s:%s" localport server remoteport)
 			     (append args (list sshserver))))
@@ -199,8 +198,7 @@ after ':'."
 (defun mew-ssh-sentinel (process event)
   (let ((pnm (process-name process)))
     (unless (mew-ssh-get-status pnm)
-      (mew-ssh-set-status pnm 'exit))
-    (mew-remove-buffer (process-buffer process))))
+      (mew-ssh-set-status pnm 'exit))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -232,7 +230,7 @@ after ':'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2005 Mew developing team.
+;; Copyright (C) 1999-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
