@@ -16,10 +16,10 @@
   '(;; parameters to be saved
     "refile"  "mark-hist"
     ;; parameters used internally
-    "scan-id" "find-key" "cursor-line" "direction" "start-point"
+    "scan-id" "scan-md5" "find-key" "cursor-line" "direction" "start-point"
     "cache-time" "summary-form" "unread-mark" "refile-back"
     "disp-msg" "case" "folder" "proto" "mid-marker" "mid-line" "ttl-line"
-    "mark-review"))
+    "mark-review" "ret-pos" "inboxp"))
 
 (mew-blinfo-defun 'mew-sinfo mew-sinfo-list)
 
@@ -31,7 +31,7 @@
     (let* ((n mew-sinfo-list-save-length)
 	   (data (make-vector n nil))
 	   (bnm (mew-summary-folder-name 'ext))
-	   (file (mew-expand-folder bnm mew-sinfo-file))
+	   (file (mew-expand-file bnm mew-sinfo-file))
 	   (i 0))
       (while (< i n)
 	(aset data i (aref mew-sinfo i))
@@ -42,7 +42,7 @@
   (when (mew-summary-p)
     (let* ((n mew-sinfo-list-save-length)
 	   (bnm (mew-summary-folder-name 'ext))
-	   (file (mew-expand-folder bnm mew-sinfo-file))
+	   (file (mew-expand-file bnm mew-sinfo-file))
 	   (i 0)
 	   data)
       (setq data (mew-lisp-load file))
@@ -95,7 +95,7 @@ files to FILES."
        (while FLD-MSGS
 	 (setq fld-msg (car FLD-MSGS))
 	 (setq FLD-MSGS (cdr FLD-MSGS))
-	 (setq FILES (cons (mew-expand-folder (car fld-msg) (cdr fld-msg))
+	 (setq FILES (cons (mew-expand-msg (car fld-msg) (cdr fld-msg))
 			   FILES)))
        (setq FILES (nreverse FILES))
        ,@body))))
@@ -254,7 +254,8 @@ and return (beg . end)."
 
 (defvar mew-mode-line-target "%p")
 (defvar mew-mode-line-format
-  `("" mew-summary-buffer-left-msgs
+  `(""
+    (mew-summary-buffer-left-msgs mew-summary-buffer-left-msgs "L%l")
     (mew-summary-buffer-raw "*")
     (mew-summary-buffer-secure-process ,mew-secure-format2)))
 
@@ -290,16 +291,10 @@ and return (beg . end)."
   (setq mew-summary-buffer-left-msgs nil))
 
 (defun mew-summary-mode-name (name)
-  (let ((in (if (mew-case-default-p mew-case-input)
-		"" mew-case-input))
-	(out (if (mew-case-default-p mew-case-output)
-		 "" mew-case-output)))
-    (if (and (string= in "") (string= out ""))
+  (let ((case (if (mew-case-default-p mew-case) "" mew-case)))
+    (if (string= case "")
 	(setq mode-name name)
-      (if (or (and mew-case-synchronize (string= in out))
-              mew-ask-flush-case)
-	  (setq mode-name (format "%s %s" name in))
-	(setq mode-name (format "%s %s:%s" name in out))))
+      (setq mode-name (format "%s %s" name case)))
     (force-mode-line-update)))
 
 (defun mew-summary-mode-line ()
@@ -426,13 +421,14 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-jump-top]	Go to the beginning of this Summary mode.
 \\[mew-summary-jump-bottom]	Go to the end of this Summary mode.
 
-\\[mew-summary-retrieve]	Retrieve messages to +inbox asynchronously
-	 according to 'mew-mailbox-type'. 
+\\[mew-summary-retrieve]	In local folders, retrieve messages to +inbox asynchronously 
+	according to 'mew-mailbox-type' and 'mew-case'. 
 	If 'mew-auto-flush-queue' is non-nil, +queue is flushed.
 	If called with '\\[universal-argument]', +queue is not flushed.
+	In remote folders, visit an inbox folder and scan with 'update.
 
 \\[mew-summary-retrieve-message]	Retrieve the rest of a truncated('T') message.
-	In a LOCAL folder: 'mew-input-case' is used for a case.  If
+	In a LOCAL folder: 'mew-case' is used for a case.  If
 	'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the message from
 	the mailbox.  When executed with '\\[universal-argument]',
 	'mew-pop-delete'/'mew-imap-delete' is considered reversed.
@@ -510,7 +506,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-exchange-marks]	Exchange the first input mark to the second one.
 
 \\[mew-summary-mark-retrieve-message]	Retrieve the rest of a truncated('T') message marked with '*'.
-	In a LOCAL folder: 'mew-input-case' is used for a case.  
+	In a LOCAL folder: 'mew-case' is used for a case.  
 	If 'mew-pop-delete'/'mew-imap-delete' is non-nil, 
 	delete the message from	the mailbox.
 	When executed with '\\[universal-argument]',
@@ -543,9 +539,6 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-cite]	Cite this message to one of drafts.
 
 \\[mew-summary-execute-external] Execute an external command according to Content-Type:.
-	If called with '\\[universal-argument]', Content-Type: is asked.
-
-\\[mew-summary-execute-command] Execute an inputted command.
 
 \\[mew-summary-recenter]	Make the current line to the center of Summary mode.
 
@@ -574,6 +567,7 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-pgp-fetch-key]	Fetch the PGP public key whose key ID appears in the X-Mew: field.
 
 \\[mew-pgp-select]	Select PGP version.
+\\[mew-passwd-change]	Change the master password.
 
 \\[mew-summary-addrbook-add]	Adding the value of From: in Message mode to Addrbook.
 	When executed with '\\[universal-argument], it will add personal information.
@@ -651,11 +645,11 @@ Virtual mode.
 	the same as that of the current message are processed.
 
 \\[mew-summary-mark-refile]	Put the 'o' mark onto all messages marked with '*'. 
-	This is very convenient to refile all messages picked by '\\[mew-summary-pick-mark]' and \"\\[mew-summary-grep-mark]\".
+	This is very convenient to refile all messages picked by '\\[mew-summary-pick]'.
 
 \\[mew-summary-mark-copy]	Put the refile mark onto all messages marked with '*', 
 	with the current folder as a candidate in addition to guessed folders.
-	This is very convenient to refile all messages picked by '\\[mew-summary-pick-mark]' and \"\\[mew-summary-grep-mark]\".
+	This is very convenient to refile all messages picked by '\\[mew-summary-pick]'.
 
 \\[mew-summary-mark-delete]	Put the 'D' mark onto all messages marked with '*'.
 \\[mew-summary-mark-unlink]	Put the 'X' mark onto all messages marked with '*'.
@@ -668,22 +662,16 @@ Virtual mode.
 	A job to delete or refile messages, which is created by this command, 
 	is queued in a queue folder (%queue for IMAP). To flush jobs in 
 	the queue, type '\\[mew-summary-send-message]' in the queue online.
-\\[mew-summary-local-copy]	Copy a cached message in a remote folder to a local folder.
-\\[mew-summary-mark-local-copy]	Copy cached message marked with '*' in a remote folder
-	to a local folder.
 
-\\[mew-summary-pick-mark]	Pick messages according to a pick pattern which you input,
-	then put the '*' mark onto them. 'mewl' is called as a picking
-	command. If called with '\\[universal-argument]', the target is	the region.
+\\[mew-summary-local-copy]	Copy a message to a local folder.
+\\[mew-summary-mark-local-copy]	Copy messages marked with '*' to a local folder. 
+\\[mew-summary-imap-copy]	Copy a message to the server side of IMAP.
+\\[mew-summary-mark-imap-copy]	Copy messages marked with '*' to the server side of IMAP.
 
-\\[mew-summary-grep-mark]	Grep messages according to a grep pattern which you input,
-	then put the '*' mark onto them. 'mew-prog-grep' is called as a
-	grep command. If called with '\\[universal-argument]', the target is the region.
-
-\\[mew-summary-cmd-mark]	Grep messages according to a grep pattern which you input,
-	then put the '*' mark onto them. You can asked to specify a grep
-	command.  If called with '\\[universal-argument]', the target is
-	the region.
+\\[mew-summary-pick]	Pick messages according to a specified pick pattern.
+	Then put the '*' mark onto them. 'mewl' or 'grep' is called as a
+	picking command. If called with '\\[universal-argument]', the
+	target is the region.
 
 \\[mew-summary-find-keyword-down]	Display a message marked with '*'
 	and find a keyword and highlight it in the forward direction.
@@ -698,10 +686,25 @@ Virtual mode.
 	first asks you a keyword. If you want to change the stored
 	keyword, execute this command with '\\[universal-argument]'.
 
-\\[mew-summary-virtual]	Go to Virtual mode which gives a single view
-	to picked messages from multiple folders. Enter a virtual
-	folder name, comma-separated folders, and a pick pattern.
+\\[mew-summary-virtual]	Making Virtual mode according to a specified pick pattern.
+	'mewl' or 'grep' is called as a picking command. If called with
+	'\\[universal-argument]', the target is the region.
 
+\\[mew-summary-search-change-method]	Change a search method.
+\\[mew-summary-search]	Pick messages according to a specified pick pattern
+	with a search method. Then put the '*' mark onto them. 
+\\[mew-summary-search-virtual]	Making Virtual mode according to a specified pick pattern
+	with a search method.
+\\[mew-summary-make-index-folder]	Make index for this folder.
+\\[mew-summary-make-index-all]	Make index for all folders.
+
+\\[mew-summary-make-thread]	This command makes threads for the Summary mode as Virtual mode,
+	then the cursor jump onto the current message in the Virtual mode. 
+	If a corresponding Virtual mode exists,	this command just visits
+	the Virtual mode.
+\\[mew-summary-regexp-make-thread]	Make threads for messages matched to a specified regular expression.
+
+\\[mew-summary-mark-thread]	Make threads for messages marked with '*'.
 \\[mew-summary-mark-virtual]	Making Virtual mode for messages marked with '*'.
 	If called with '\\[universal-argument]', you can specify a target mark.
 
@@ -714,12 +717,6 @@ Virtual mode.
 \\[mew-summary-delete-folder]	Delete this folder.
 \\[mew-summary-rename-folder]	Rename this folder.
 
-\\[mew-summary-make-thread]	This command makes threads for the Summary mode as Virtual mode,
-	then the cursor jump onto the current message in the Virtual mode. 
-	If a corresponding Virtual mode exists,	this command just visits
-	the Virtual mode.
-\\[mew-summary-regexp-make-thread]	Make threads for messages matched to a specified regular expression.
-
 \\[mew-summary-learn-spam]	Learn that this message is a spam.
 
 \\[mew-summary-learn-ham]	Learn that this message is a ham.
@@ -812,6 +809,7 @@ is equivalent to
 (defun mew-summary-reset ()
   (mew-unhighlight-cursor-line)
   (mew-window-configure 'summary)
+  (mew-remove-buffer (mew-buffer-message))
   (mew-current-set nil nil nil)
   (mew-summary-reset-mode-line)
   (mew-decode-syntax-delete))
@@ -820,7 +818,7 @@ is equivalent to
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2005 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
