@@ -12,6 +12,11 @@
 ;;; Subfunctions
 ;;;
 
+(defun mew-xemacs-redraw-toolbar ()
+  (when (and mew-icon-p (specifier-instance default-toolbar-visible-p))
+    (set-specifier default-toolbar-visible-p nil)
+    (set-specifier default-toolbar-visible-p t)))
+
 (defmacro mew-summary-prepare-draft (&rest body)
   "Common procedure to prepare a draft."
   `(progn
@@ -20,11 +25,9 @@
 	   ,@body
 	   ;; XEmacs does not draw attachments unless sit for 0...
 	   (mew-redraw)
+	   (if quit-flag (setq quit-flag nil))
 	   ;; XEmacs does not draw toolbar, so...
-	   (when (and mew-xemacs-p mew-icon-p
-		      (specifier-instance default-toolbar-visible-p))
-	     (set-specifier default-toolbar-visible-p nil)
-	     (set-specifier default-toolbar-visible-p t)))
+	   (if mew-xemacs-p (mew-xemacs-redraw-toolbar)))
        (mew-draft-save-buffer)) ;; to make sure not to use this draft again
      (mew-set-file-modes (buffer-file-name))
      (mew-touch-folder mew-draft-folder)
@@ -58,6 +61,18 @@
 ;;; Sending
 ;;;
 
+(defun mew-summary-set-message-buffer (fld msg)
+  ;; need to make a cache or a message buffer.
+  (mew-summary-toggle-disp-msg 'on)
+  ;; Since we will switch to a draft buffer,
+  ;; the window of the draft buffer must not be deleted.
+  ;; So, binding mew-use-full-window to nil.
+  (let ((mew-use-full-window nil))
+    (mew-summary-display))
+  (set-buffer (mew-buffer-message))
+  ;; header exists only in cache if multipart
+  (unless (mew-msghdr-p) (set-buffer (mew-cache-hit fld msg))))
+
 (defun mew-summary-write (&optional from)
   "Write a message. A new draft is prepared in Draft mode.
 If called with '\\[universal-argument]', the From: address of
@@ -72,11 +87,7 @@ the current message is copied to To: in a draft."
        (if (not (and fld msg))
 	   (message "No message")
 	 (save-excursion
-	   (set-buffer (or (save-excursion
-			     (set-buffer (mew-buffer-message))
-			     (if (mew-msghder-p) (current-buffer)))
-			   ;; header exists only in cache if multipart
-			   (mew-cache-hit fld msg)))
+	   (mew-summary-set-message-buffer fld msg)
 	   (setq to (mew-addrstr-parse-address (mew-header-get-value mew-from:))))
 	 (mew-summary-send to)
 	 (goto-char (point-min))
@@ -283,7 +294,6 @@ You may want to set 'mew-reply-all-alist' to:
   (interactive "P")
   (mew-summary-msg-or-part
    (mew-summary-not-in-draft
-    (mew-summary-toggle-disp-msg 'on)
     (mew-current-set-window-config)
     (let ((owin (selected-window))
 	  (fld (mew-summary-folder-name))
@@ -301,15 +311,7 @@ You may want to set 'mew-reply-all-alist' to:
 	 (setq cwin (selected-window)) ;; draft
 	 (setq cbuf (window-buffer cwin))
 	 (select-window owin)
-	 ;; need to make a cache or a message buffer.
-	 (let ((mew-use-full-window nil))
-	   (mew-summary-display nil))
-	 ;; see also mew-draft-cite
-	 (set-buffer (or (save-excursion
-			   (set-buffer (mew-buffer-message))
-			   (if (mew-msghder-p) (current-buffer)))
-			 ;; header exists only in cache if multipart
-			 (mew-cache-hit fld msg)))
+	 (mew-summary-set-message-buffer fld msg)
 	 (when mew-case-guess-when-replied
 	   (setq case (mew-draft-get-case-by-guess
 		       mew-case-guess-when-replied-alist)))
@@ -391,7 +393,7 @@ Draft mode and this message is automatically attached."
     (let* ((owin (selected-window))
 	   (fld (mew-summary-folder-name))
 	   (msg (mew-summary-message-number2))
-	   (file (mew-expand-folder fld msg))
+	   (file (mew-expand-msg fld msg))
 	   (draft (mew-folder-new-message mew-draft-folder))
 	   (draftdir (file-name-nondirectory draft))
 	   (to (and mew-ask-to (mew-input-address (concat mew-to: " "))))
@@ -403,15 +405,7 @@ Draft mode and this message is automatically attached."
        (mew-delete-directory-recursively (mew-attachdir draft))
        (setq cwin (selected-window)) ;; draft
        (select-window owin)
-       ;; need to make a cache or a message buffer.
-       (let ((mew-use-full-window nil))
-	 (mew-summary-display 'redisplay))
-       ;;
-       (set-buffer (or (save-excursion
-			 (set-buffer (mew-buffer-message))
-			 (if (mew-msghder-p) (current-buffer)))
-		       ;; header exists only in cache if multipart
-		       (mew-cache-hit fld msg)))
+       (mew-summary-set-message-buffer fld msg)
        (setq subject (mew-header-get-value mew-subj:))
        (if subject
 	   (setq fwsubject (mew-subject-simplify (concat mew-forward-string subject))))
@@ -459,7 +453,7 @@ attached."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2005 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
