@@ -232,6 +232,7 @@ in draft buffer.")
     ("Resent-Cc:"   . mew-complete-address)
     ("Resent-Dcc:"  . mew-complete-address)
     ("Resent-Bcc:"  . mew-complete-address)
+    ("Resent-Fcc:"  . mew-complete-local-folder)
     ("Newsgroups:"  . mew-complete-newsgroups)
     ("Followup-To:" . mew-complete-newsgroups))
   "*Completion function alist concerned with the key."
@@ -280,7 +281,7 @@ in draft buffer.")
   "*The default Content-Type: for a file whose suffix is unknown.")
 
 (defvar mew-mime-content-type
-  '(("multipart"    nil         nil     nil            mew-icon-multipart)
+  `(("multipart"    nil         nil     nil            mew-icon-multipart)
     ;;
     ("audio/basic"  "\\.au$"    mew-b64 mew-prog-audio mew-icon-audio)
     ("audio/x-wav"  "\\.wav$"   mew-b64 mew-prog-audio mew-icon-audio)
@@ -309,7 +310,7 @@ in draft buffer.")
     ("video/quicktime" "\\.mov$"   mew-b64 mew-prog-video mew-icon-video)
     ("video/x-msvideo" "\\.avi$"   mew-b64 mew-prog-video mew-icon-video)
     ;;
-    ("message/rfc822"          "^[0-9]+$" nil
+    ("message/rfc822"          ,(format "^[0-9]+\\(%s\\)?$" mew-suffix) nil
      mew-prog-rfc822           mew-icon-message/rfc822)
     ("message/external-body"   "\\.ext$"  nil
      mew-prog-external-body    mew-icon-message/external-body)
@@ -320,8 +321,6 @@ in draft buffer.")
      mew-prog-postscript             mew-icon-application/postscript)
     ("application/pdf"               "\\.pdf$"  mew-b64
      mew-prog-pdf                    mew-icon-application/postscript)
-    ("application/xml"               "\\.xml$"  mew-b64
-     mew-prog-xml2                   mew-icon-text)
     ("application/msword"            "\\.doc$"  mew-b64
      mew-prog-msword                 mew-icon-text)
     ("application/vnd.ms-excel"      "\\.xl[st]$" mew-b64
@@ -379,11 +378,13 @@ in draft buffer.")
      mew-prog-rfc822-headers     mew-icon-message/rfc822)
     ("text"         "^$"        nil     mew-prog-text      mew-icon-text)
     ;; Unknown CT: matches here.
+    ("application/xml"               "\\.xml$"  mew-b64
+     mew-prog-xml2                   mew-icon-text)
     (t               "^$"       nil   mew-prog-octet-stream mew-icon-unknown)
     ;; Unknown suffix matches here and return the entry specified 
     ;; by mew-content-type.
     (nil             ".*"))
-  "Database for MIME content type.
+  "\\<mew-summary-mode-map>Database for MIME content type.
 This is a list of entries which consist of <content-type>, 
 <regular expression of file suffix>, <content-transfer-encoding>, 
 <symbol for visualizer>, <symbol for icon>, <auxiliary data>.
@@ -406,17 +407,47 @@ content-transfer-encoding when composing.
 Each symbol specified at <symbol for visualizer> should have a value
 whose format is one of followings:
 
-- symbol
-	symbol is a name of Elisp function for inline.
-- (symbol1 symbol2)
-	symbol1 is a name of Elisp function for inline.
-	symbol2 is a name of Elisp function for external.
-- (string list nil-or-t)
-	string is a name of an external program.
-	list is a list of arguments for the external program.
-	nil-or-t: 
+- \"prog\"
+	\"prog\" is an external program.
+	(1) The program name is displayed.
+	(2) \"prog\" is executed asynchronously.
+- func
+	<func> is a function.
+	(1) <func> is called.
+	(2) <func> is called.
+- (\"prog\" args async)
+	\"prog\" is an external program.
+	<args> is a list of arguments for the external program.
+	<async>
 		If nil, the external program is called synchronously.
 		If t, the external program is called asynchronously.
+	(1) The program name is displayed.
+	(2) \"prog\" is executed asynchronously with <args>.
+- (nil \"prog\")
+	Equivalent to \"prog\".
+- (nil (\"prog\" args async))
+	Equivalent to (\"prog\" args async).
+- (nil func2)
+	(1) Displayed 'type \\[mew-summary-execute-external]'.
+	(2) <func2> is called. 
+- (func1 func2)
+	(1) <func1> is called.
+	(2) <func2> is called.
+	    If the original content-type is Application/Octet-Stream,
+	    you are asked to choose <func1> or <func2>.
+- (func1 \"prog\")
+	(1) <func1> is called. 
+	(2) \"prog\" is executed asynchronously.
+	    If the original content-type is Application/Octet-Stream,
+	    you are asked to choose <func1> or \"prog\".
+- (func1 (\"prog\" args async)) 
+	(1) <func1> is called. 
+	(2) \"prog\" is executed asynchronously with <args>.
+	    If the original content-type is Application/Octet-Stream,
+	    you are asked to choose <func1> or \"prog\".
+
+Note that (1) indicates the action for '\\[mew-summary-display]' and
+(2) indicates the action for '\\[mew-summary-execute-external]'.
 
 If you want to add an entry for new content-type, please let the author
 know. Such an entry should be shared by all users and be included in
@@ -547,7 +578,9 @@ the next version of Mew.")
     (,mew-references:    unstruct   unstruct)
     (,mew-in-reply-to:   unstruct   unstruct)
     (,mew-x-face:	 unstruct   unstruct)
-    (,mew-face:          unstruct   unstruct))
+    (,mew-face:          unstruct   unstruct)
+    ("Domainkey-Signature:" unstruct unstruct) ;; capitalized
+    ("Dkim-Signature:"      unstruct unstruct)) ;; capitalized
   "(field enc dec)")
 
 (defsubst mew-field-type-for-encoding (key)
@@ -561,107 +594,8 @@ the next version of Mew.")
 ;;; Theme
 ;;;
 
-(defvar mew-theme-file "mew-theme")
-
-(defface mew-face-header-subject nil
-  "*Face to highlight the value of Subject:"
-  :group 'mew-highlight)
-
-(defface mew-face-header-from nil
-  "*Face to highlight the value of From:"
-  :group 'mew-highlight)
-
-(defface mew-face-header-to nil
-  "*Face to highlight the value of To:"
-  :group 'mew-highlight)
-
-(defface mew-face-header-date nil
-  "*Face to highlight the value of Date:"
-  :group 'mew-highlight)
-
-(defface mew-face-header-key nil
-  "*Face to highlight by default"
-  :group 'mew-highlight)
-
-(defface mew-face-header-private nil
-  "*Face to highlight private field-keys"
-  :group 'mew-highlight)
-
-(defface mew-face-header-important nil
-  "*Face to highlight important field-keys"
-  :group 'mew-highlight)
-
-(defface mew-face-header-marginal nil
-  "*Face to highlight marginal field-values"
-  :group 'mew-highlight)
-
-(defface mew-face-header-xmew nil
-  "*Face to highlight the value of X-Mew:"
-  :group 'mew-highlight)
-
-(defface mew-face-header-xmew-bad nil
-  "*Face to highlight the value of X-Mew: in bad cases"
-  :group 'mew-highlight)
-
-(defface mew-face-body-url nil
-  "*Face to highlight URL in Message/Draft mode"
-  :group 'mew-highlight)
-  
-(defface mew-face-body-comment nil
-  "*Face to highlight comments in a body"
-  :group 'mew-highlight)
-
-(defface mew-face-body-cite1 nil
-  "*Face to highlight the first citation"
-  :group 'mew-highlight)
-
-(defface mew-face-body-cite2 nil
-  "*Face to highlight the second citation"
-  :group 'mew-highlight)
-
-(defface mew-face-body-cite3 nil
-  "*Face to highlight the third citation"
-  :group 'mew-highlight)
-
-(defface mew-face-body-cite4 nil
-  "*Face to highlight the forth citation"
-  :group 'mew-highlight)
-
-(defface mew-face-body-cite5 nil
-  "*Face to highlight the fifth citation"
-  :group 'mew-highlight)
-
-(defface mew-face-mark-review nil
-  "*Face to highlight the review mark"
-  :group 'mew-highlight)
-
-(defface mew-face-mark-escape nil
-  "*Face to highlight the escape mark"
-  :group 'mew-highlight)
-
-(defface mew-face-mark-delete nil
-  "*Face to highlight the delete mark"
-  :group 'mew-highlight)
-
-(defface mew-face-mark-unlink nil
-  "*Face to highlight the unlink mark"
-  :group 'mew-highlight)
-
-(defface mew-face-mark-refile nil
-  "*Face to highlight the refile mark"
-  :group 'mew-highlight)
-
-(defface mew-face-mark-unread nil
-  "*Face to highlight the unread mark"
-  :group 'mew-highlight)
-
-(defface mew-face-eof-message nil
-  "*Face to highlight the 'end of message' string"
-  :group 'mew-highlight)
-
-(defface mew-face-eof-part nil
-  "*Face to highlight the 'end of part' string"
-  :group 'mew-highlight)
+(defvar mew-theme-file nil
+  "The file name which contains theme.")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -669,7 +603,7 @@ the next version of Mew.")
 ;;;
 
 (defcustom mew-field-spec
-  '(("^Resent-\\(From\\|To\\|Cc\\|Date\\)" t
+  '(("^Resent-\\(Sender\\|From\\|To\\|Cc\\|Date\\)" t
      mew-face-header-important
      mew-face-header-important)
     ("^Subject:$" t
@@ -690,15 +624,23 @@ the next version of Mew.")
     ("^Date:$" t
      mew-face-header-important
      mew-face-header-date)
+    ("^Sender:$" t)
     ("^Reply-To:$" t)
-    ("^X-Mailer:$" t)
+    ("^\\(X-Mailer\\|User-Agent\\):$" t)
     ("^X-Mew:$" t
      mew-face-header-important
      mew-face-header-xmew)
-    ("^\\(Received\\|Return-Path\\|Sender\\|Errors-To\\):$" nil)
+    ("^\\(Received\\|Return-Path\\|Errors-To\\):$" nil)
     ("^\\(Path\\|Distribution\\|Xref\\):$" nil)
     ("^NNTP-Posting-" nil)
     ("^\\(Message-Id\\|Posted\\|In-Reply-To\\|References\\|Precedence\\):$" nil)
+    ("^DomainKey-Signature:$" nil)
+    ("^DKIM-Signature:$" nil)
+    ("^Authentication-Results:$" t
+     mew-face-header-important
+     mew-face-header-xmew
+     ("fail" mew-face-header-xmew-bad
+      "softfail" mew-face-header-xmew-bad))
     ("^Delivered-" nil)
     ("^List-" nil) ;; RFC 2369
 ;;    ("^Content-" t)
@@ -742,6 +684,9 @@ present, mew-face-header-marginal is used."
 (defsubst mew-nspec-valface (nspec)
   (nth 4 nspec))
 
+(defsubst mew-nspec-extraface (nspec)
+  (nth 5 nspec))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Highlight body
@@ -907,7 +852,7 @@ function which returns nil or a mark or a string.
 If you are using 'spamassassin' which adds the \"X-Spam-Flag:\" field
 to messages and puts them in your mailbox, configure as follows:
 
-(setq mew-spam: \"X-Spam-Flag:\") ;; must be in \".emacs\"
+(setq mew-spam: \"X-Spam-Flag:\")
 
 (defun mew-spam-assassin (val)
   (let ((case-fold-search t))
@@ -924,7 +869,7 @@ value is \"Yes\" are automatically marked with 'D' since the
 If you are using 'bogofilter' which adds the \"X-Bogosity:\" field
 to messages and puts them to your mailbox, configure as follows:
 
-(setq mew-spam: \"X-Bogosity:\") ;; must be in \".emacs\" but default
+(setq mew-spam: \"X-Bogosity:\")
 
 (defun mew-spam-bogofilter (val)
   (let ((case-fold-search t))
@@ -1084,15 +1029,15 @@ An example is as follows:
 
 (setq mew-config-alist
       '((\"mew\"
-	 (\"mail-domain\"  . \"mew.org\")
+	 (\"mail-domain\"  . \"example.org\")
 	 (\"inbox-folder\" . \"+inbox-mew\"))
 	(\"keio\"
-	 (\"cc\"           . \"kazu@iijlab.net\")
+	 (\"cc\"           . \"kazu@example.jp\")
 	 (\"user\"         . \"pooh\")
-	 (\"mail-domain\"  . \"sfc.keio.ac.jp\"))
+	 (\"mail-domain\"  . \"example.net\"))
 	(\"default\"
 	 (\"name\"         . \"Kazu Yamamoto\")
-	 (\"mail-domain\"  . \"iijlab.net\"))))
+	 (\"mail-domain\"  . \"example.jp\"))))
 "
   :group 'mew-env
   :type '(alist :key-type string
@@ -1107,7 +1052,7 @@ An example is as follows:
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2005 Mew developing team.
+;; Copyright (C) 2000-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
